# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/community/subscription_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.annotations import scope_pb2 as eolymp_dot_annotations_dot_scope__pb2
from eolymp.community import subscription_pb2 as eolymp_dot_community_dot_subscription__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n+eolymp/community/subscription_service.proto\x12\x10\x65olymp.community\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a\x1e\x65olymp/annotations/scope.proto\x1a#eolymp/community/subscription.proto\"6\n\x16ListSubscriptionsInput\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\"W\n\x17ListSubscriptionsOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12-\n\x05items\x18\x02 \x03(\x0b\x32\x1e.eolymp.community.Subscription\"4\n\x19\x44\x65scribeSubscriptionInput\x12\x17\n\x0fsubscription_id\x18\x01 \x01(\t\"R\n\x1a\x44\x65scribeSubscriptionOutput\x12\x34\n\x0csubscription\x18\x01 \x01(\x0b\x32\x1e.eolymp.community.Subscription2\x9a\x03\n\x13SubscriptionService\x12\xcd\x01\n\x14\x44\x65scribeSubscription\x12+.eolymp.community.DescribeSubscriptionInput\x1a,.eolymp.community.DescribeSubscriptionOutput\"Z\x82\xe3\n\x1f\x8a\xe3\n\x1b\x63ommunity:subscription:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x82\xd3\xe4\x93\x02\"\x12 /subscriptions/{subscription_id}\x12\xb2\x01\n\x11ListSubscriptions\x12(.eolymp.community.ListSubscriptionsInput\x1a).eolymp.community.ListSubscriptionsOutput\"H\x82\xe3\n\x1f\x8a\xe3\n\x1b\x63ommunity:subscription:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02\x10\x12\x0e/subscriptionsB5Z3github.com/eolymp/go-sdk/eolymp/community;communityb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.community.subscription_service_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z3github.com/eolymp/go-sdk/eolymp/community;community'
  _SUBSCRIPTIONSERVICE.methods_by_name['DescribeSubscription']._options = None
  _SUBSCRIPTIONSERVICE.methods_by_name['DescribeSubscription']._serialized_options = b'\202\343\n\037\212\343\n\033community:subscription:read\352\342\n\013\365\342\n\000\000\240@\370\342\n2\202\323\344\223\002\"\022 /subscriptions/{subscription_id}'
  _SUBSCRIPTIONSERVICE.methods_by_name['ListSubscriptions']._options = None
  _SUBSCRIPTIONSERVICE.methods_by_name['ListSubscriptions']._serialized_options = b'\202\343\n\037\212\343\n\033community:subscription:read\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\323\344\223\002\020\022\016/subscriptions'
  _LISTSUBSCRIPTIONSINPUT._serialized_start=201
  _LISTSUBSCRIPTIONSINPUT._serialized_end=255
  _LISTSUBSCRIPTIONSOUTPUT._serialized_start=257
  _LISTSUBSCRIPTIONSOUTPUT._serialized_end=344
  _DESCRIBESUBSCRIPTIONINPUT._serialized_start=346
  _DESCRIBESUBSCRIPTIONINPUT._serialized_end=398
  _DESCRIBESUBSCRIPTIONOUTPUT._serialized_start=400
  _DESCRIBESUBSCRIPTIONOUTPUT._serialized_end=482
  _SUBSCRIPTIONSERVICE._serialized_start=485
  _SUBSCRIPTIONSERVICE._serialized_end=895
# @@protoc_insertion_point(module_scope)



from eolymp.ecm import content_pb2 as _content_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Tier(_message.Message):
    __slots__ = ["description", "id", "image", "name", "summary"]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    IMAGE_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    SUMMARY_FIELD_NUMBER: _ClassVar[int]
    description: _content_pb2.Content
    id: str
    image: str
    name: str
    summary: str
    def __init__(self, id: _Optional[str] = ..., name: _Optional[str] = ..., summary: _Optional[str] = ..., description: _Optional[_Union[_content_pb2.Content, _Mapping]] = ..., image: _Optional[str] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/l10n/project.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x19\x65olymp/l10n/project.proto\x12\x0b\x65olymp.l10n\"T\n\x07Project\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0b\n\x03url\x18\x04 \x01(\t\x12\x10\n\x08logo_url\x18\x03 \x01(\t\x12\x10\n\x08home_url\x18\x05 \x01(\tB+Z)github.com/eolymp/go-sdk/eolymp/l10n;l10nb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.l10n.project_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z)github.com/eolymp/go-sdk/eolymp/l10n;l10n'
  _PROJECT._serialized_start=42
  _PROJECT._serialized_end=126
# @@protoc_insertion_point(module_scope)



from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Contest(_message.Message):
    __slots__ = ["appearance", "domain", "duration", "ends_at", "ends_in", "environment", "featured_until", "format", "id", "join_unofficially", "name", "participation_mode", "scoreboard", "space_id", "starts_at", "starts_in", "status", "taxonomy", "upsolve", "url", "visibility"]
    class Format(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = []
    class ParticipationMode(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = []
    class Status(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = []
    class Visibility(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = []
    class Appearance(_message.Message):
        __slots__ = ["description", "logo_image", "primary_color", "secondary_color", "tagline", "title"]
        DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
        LOGO_IMAGE_FIELD_NUMBER: _ClassVar[int]
        PRIMARY_COLOR_FIELD_NUMBER: _ClassVar[int]
        SECONDARY_COLOR_FIELD_NUMBER: _ClassVar[int]
        TAGLINE_FIELD_NUMBER: _ClassVar[int]
        TITLE_FIELD_NUMBER: _ClassVar[int]
        description: str
        logo_image: str
        primary_color: str
        secondary_color: str
        tagline: str
        title: str
        def __init__(self, title: _Optional[str] = ..., tagline: _Optional[str] = ..., description: _Optional[str] = ..., logo_image: _Optional[str] = ..., primary_color: _Optional[str] = ..., secondary_color: _Optional[str] = ...) -> None: ...
    class Environment(_message.Message):
        __slots__ = ["allowed_runtimes"]
        ALLOWED_RUNTIMES_FIELD_NUMBER: _ClassVar[int]
        allowed_runtimes: _containers.RepeatedScalarFieldContainer[str]
        def __init__(self, allowed_runtimes: _Optional[_Iterable[str]] = ...) -> None: ...
    class Scoreboard(_message.Message):
        __slots__ = ["attempt_penalty", "freezing_time", "unfreeze_delay", "use_name_in_scoreboard", "visibility"]
        class Visibility(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
            __slots__ = []
        ATTEMPT_PENALTY_FIELD_NUMBER: _ClassVar[int]
        FREEZING_TIME_FIELD_NUMBER: _ClassVar[int]
        INTERNAL: Contest.Scoreboard.Visibility
        INVISIBLE: Contest.Scoreboard.Visibility
        PUBLIC: Contest.Scoreboard.Visibility
        UNFREEZE_DELAY_FIELD_NUMBER: _ClassVar[int]
        UNKNOWN_VISIBILITY: Contest.Scoreboard.Visibility
        USE_NAME_IN_SCOREBOARD_FIELD_NUMBER: _ClassVar[int]
        VISIBILITY_FIELD_NUMBER: _ClassVar[int]
        attempt_penalty: int
        freezing_time: int
        unfreeze_delay: int
        use_name_in_scoreboard: bool
        visibility: Contest.Scoreboard.Visibility
        def __init__(self, visibility: _Optional[_Union[Contest.Scoreboard.Visibility, str]] = ..., freezing_time: _Optional[int] = ..., unfreeze_delay: _Optional[int] = ..., attempt_penalty: _Optional[int] = ..., use_name_in_scoreboard: bool = ...) -> None: ...
    class Taxonomy(_message.Message):
        __slots__ = ["city", "country", "difficulty", "region", "scale", "series", "year"]
        class Scale(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
            __slots__ = []
        CITY_FIELD_NUMBER: _ClassVar[int]
        COUNTRY_FIELD_NUMBER: _ClassVar[int]
        DIFFICULTY_FIELD_NUMBER: _ClassVar[int]
        INTERNATIONAL: Contest.Taxonomy.Scale
        LOCAL: Contest.Taxonomy.Scale
        NATIONAL: Contest.Taxonomy.Scale
        REGIONAL: Contest.Taxonomy.Scale
        REGION_FIELD_NUMBER: _ClassVar[int]
        SCALE_FIELD_NUMBER: _ClassVar[int]
        SERIES_FIELD_NUMBER: _ClassVar[int]
        UNKNOWN_SCALE: Contest.Taxonomy.Scale
        YEAR_FIELD_NUMBER: _ClassVar[int]
        city: str
        country: str
        difficulty: int
        region: str
        scale: Contest.Taxonomy.Scale
        series: str
        year: int
        def __init__(self, year: _Optional[int] = ..., series: _Optional[str] = ..., scale: _Optional[_Union[Contest.Taxonomy.Scale, str]] = ..., difficulty: _Optional[int] = ..., country: _Optional[str] = ..., region: _Optional[str] = ..., city: _Optional[str] = ...) -> None: ...
    class Upsolve(_message.Message):
        __slots__ = ["free_upsolve", "virtual_upsolve"]
        FREE_UPSOLVE_FIELD_NUMBER: _ClassVar[int]
        VIRTUAL_UPSOLVE_FIELD_NUMBER: _ClassVar[int]
        free_upsolve: bool
        virtual_upsolve: bool
        def __init__(self, free_upsolve: bool = ..., virtual_upsolve: bool = ...) -> None: ...
    APPEARANCE_FIELD_NUMBER: _ClassVar[int]
    COMPLETE: Contest.Status
    DOMAIN_FIELD_NUMBER: _ClassVar[int]
    DURATION_FIELD_NUMBER: _ClassVar[int]
    ENDS_AT_FIELD_NUMBER: _ClassVar[int]
    ENDS_IN_FIELD_NUMBER: _ClassVar[int]
    ENVIRONMENT_FIELD_NUMBER: _ClassVar[int]
    FEATURED_UNTIL_FIELD_NUMBER: _ClassVar[int]
    FORMAT_FIELD_NUMBER: _ClassVar[int]
    FORMAT_UNKNOWN: Contest.Format
    FROZEN: Contest.Status
    ICPC: Contest.Format
    ID_FIELD_NUMBER: _ClassVar[int]
    IOI: Contest.Format
    JOIN_UNOFFICIALLY_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    ONLINE: Contest.ParticipationMode
    OPEN: Contest.Status
    PARTICIPATION_MODE_FIELD_NUMBER: _ClassVar[int]
    PARTICIPATION_MODE_UNKNOWN: Contest.ParticipationMode
    PRIVATE: Contest.Visibility
    PUBLIC: Contest.Visibility
    SCHEDULED: Contest.Status
    SCOREBOARD_FIELD_NUMBER: _ClassVar[int]
    SPACE_ID_FIELD_NUMBER: _ClassVar[int]
    STARTS_AT_FIELD_NUMBER: _ClassVar[int]
    STARTS_IN_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    STATUS_UNKNOWN: Contest.Status
    SUSPENDED: Contest.Status
    TAXONOMY_FIELD_NUMBER: _ClassVar[int]
    UNLISTED: Contest.Visibility
    UPSOLVE_FIELD_NUMBER: _ClassVar[int]
    URL_FIELD_NUMBER: _ClassVar[int]
    VIRTUAL: Contest.ParticipationMode
    VISIBILITY_FIELD_NUMBER: _ClassVar[int]
    VISIBILITY_UNKNOWN: Contest.Visibility
    appearance: Contest.Appearance
    domain: str
    duration: int
    ends_at: _timestamp_pb2.Timestamp
    ends_in: int
    environment: Contest.Environment
    featured_until: _timestamp_pb2.Timestamp
    format: Contest.Format
    id: str
    join_unofficially: bool
    name: str
    participation_mode: Contest.ParticipationMode
    scoreboard: Contest.Scoreboard
    space_id: str
    starts_at: _timestamp_pb2.Timestamp
    starts_in: int
    status: Contest.Status
    taxonomy: Contest.Taxonomy
    upsolve: Contest.Upsolve
    url: str
    visibility: Contest.Visibility
    def __init__(self, id: _Optional[str] = ..., url: _Optional[str] = ..., name: _Optional[str] = ..., starts_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., starts_in: _Optional[int] = ..., ends_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., ends_in: _Optional[int] = ..., featured_until: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., duration: _Optional[int] = ..., status: _Optional[_Union[Contest.Status, str]] = ..., visibility: _Optional[_Union[Contest.Visibility, str]] = ..., join_unofficially: bool = ..., participation_mode: _Optional[_Union[Contest.ParticipationMode, str]] = ..., format: _Optional[_Union[Contest.Format, str]] = ..., domain: _Optional[str] = ..., space_id: _Optional[str] = ..., taxonomy: _Optional[_Union[Contest.Taxonomy, _Mapping]] = ..., appearance: _Optional[_Union[Contest.Appearance, _Mapping]] = ..., environment: _Optional[_Union[Contest.Environment, _Mapping]] = ..., upsolve: _Optional[_Union[Contest.Upsolve, _Mapping]] = ..., scoreboard: _Optional[_Union[Contest.Scoreboard, _Mapping]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/oauth2/oauth2.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1a\x65olymp/oauth2/oauth2.proto\x12\reolymp.oauth2\x1a\"eolymp/annotations/ratelimit.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xd5\x02\n\nTokenInput\x12\x37\n\ngrant_type\x18\x01 \x01(\x0e\x32#.eolymp.oauth2.TokenInput.GrantType\x12\x10\n\x08username\x18\x02 \x01(\t\x12\x10\n\x08password\x18\x03 \x01(\t\x12\x11\n\tclient_id\x18\x04 \x01(\t\x12\x15\n\rclient_secret\x18\x05 \x01(\t\x12\x0c\n\x04\x63ode\x18\x06 \x01(\t\x12\x15\n\rcode_verifier\x18\x07 \x01(\t\x12\r\n\x05scope\x18\x08 \x01(\t\x12\x15\n\rrefresh_token\x18\t \x01(\t\x12\x14\n\x0credirect_uri\x18\n \x01(\t\"_\n\tGrantType\x12\x08\n\x04NONE\x10\x00\x12\x0c\n\x08PASSWORD\x10\x01\x12\x16\n\x12\x41UTHORIZATION_CODE\x10\x02\x12\x11\n\rREFRESH_TOKEN\x10\x03\x12\x0f\n\x0bGOOGLE_CODE\x10\x04\"\x83\x02\n\x0bTokenOutput\x12\x14\n\x0c\x61\x63\x63\x65ss_token\x18\x01 \x01(\t\x12\x12\n\ntoken_type\x18\x02 \x01(\t\x12\x12\n\nexpires_in\x18\x03 \x01(\r\x12\x15\n\rrefresh_token\x18\x04 \x01(\t\x12\r\n\x05scope\x18\x05 \x01(\t\x12\x10\n\x08id_token\x18\x64 \x01(\t\x12\x10\n\x07subject\x18\x84\x07 \x01(\t\x12\x0f\n\x06issuer\x18\x85\x07 \x01(\t\x12\r\n\x04name\x18\x86\x07 \x01(\t\x12\x11\n\x08nickname\x18\x87\x07 \x01(\t\x12\x10\n\x07picture\x18\x88\x07 \x01(\t\x12\x0e\n\x05\x65mail\x18\x89\x07 \x01(\t\x12\x17\n\x0e\x65mail_verified\x18\x8a\x07 \x01(\x08\"\xa5\x01\n\x0e\x41uthorizeInput\x12\x11\n\tclient_id\x18\x01 \x01(\t\x12\x16\n\x0e\x63ode_challenge\x18\x02 \x01(\t\x12\x1d\n\x15\x63ode_challenge_method\x18\x03 \x01(\t\x12\x14\n\x0credirect_uri\x18\x04 \x01(\t\x12\x15\n\rresponse_type\x18\x05 \x01(\t\x12\r\n\x05scope\x18\x06 \x01(\t\x12\r\n\x05state\x18\x07 \x01(\t\"\'\n\x0f\x41uthorizeOutput\x12\x14\n\x0credirect_uri\x18\x01 \x01(\t\",\n\rCallbackInput\x12\x0c\n\x04\x63ode\x18\x01 \x01(\t\x12\r\n\x05state\x18\x02 \x01(\t\"&\n\x0e\x43\x61llbackOutput\x12\x14\n\x0credirect_uri\x18\x01 \x01(\t\"\x0f\n\rUserInfoInput\"\xe8\x01\n\x0eUserInfoOutput\x12\x0e\n\x06issuer\x18\x01 \x01(\t\x12\x0f\n\x07subject\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x12\n\ngiven_name\x18\x04 \x01(\t\x12\x13\n\x0b\x66\x61mily_name\x18\x05 \x01(\t\x12\x13\n\x0bmiddle_name\x18\x06 \x01(\t\x12\x10\n\x08nickname\x18\x07 \x01(\t\x12\x0f\n\x07picture\x18\x08 \x01(\t\x12\r\n\x05\x65mail\x18\t \x01(\t\x12\x16\n\x0e\x65mail_verified\x18\n \x01(\x08\x12\x0e\n\x06locale\x18\x0b \x01(\t\x12\x0f\n\x07profile\x18\x0c \x01(\t\" \n\x0fIntrospectInput\x12\r\n\x05token\x18\x01 \x01(\t\"\xf8\x01\n\x10IntrospectOutput\x12\x0e\n\x06\x61\x63tive\x18\x01 \x01(\x08\x12\r\n\x05scope\x18\x02 \x01(\t\x12*\n\x06\x65xpire\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0f\n\x07subject\x18\x04 \x01(\t\x12\x10\n\x08\x61udience\x18\x05 \x01(\t\x12\x0e\n\x06issuer\x18\x06 \x01(\t\x12\x0c\n\x04name\x18\x64 \x01(\t\x12\x10\n\x08nickname\x18\x65 \x01(\t\x12\x0f\n\x07picture\x18\x66 \x01(\t\x12\r\n\x05\x65mail\x18g \x01(\t\x12\x16\n\x0e\x65mail_verified\x18h \x01(\x08\x12\x0e\n\x06locale\x18i \x01(\t\"\xa4\x01\n\rAuthCodeInput\x12\x11\n\tclient_id\x18\x01 \x01(\t\x12\x16\n\x0e\x63ode_challenge\x18\x02 \x01(\t\x12\x1d\n\x15\x63ode_challenge_method\x18\x03 \x01(\t\x12\x14\n\x0credirect_uri\x18\x04 \x01(\t\x12\x15\n\rresponse_type\x18\x05 \x01(\t\x12\r\n\x05scope\x18\x06 \x01(\t\x12\r\n\x05state\x18\x07 \x01(\t\"B\n\x0e\x41uthCodeOutput\x12\x1a\n\x12\x61uthorization_code\x18\x01 \x01(\t\x12\x14\n\x0credirect_uri\x18\x02 \x01(\t\"\x1c\n\x0bRevokeInput\x12\r\n\x05token\x18\x01 \x01(\t\"\x0e\n\x0cRevokeOutput2\xfe\x04\n\x06OAuth2\x12P\n\x05Token\x12\x19.eolymp.oauth2.TokenInput\x1a\x1a.eolymp.oauth2.TokenOutput\"\x10\xea\xe2\n\x0c\xf5\xe2\n\x00\x00\xf0\x41\xf8\xe2\n\xac\x02\x12Y\n\x08UserInfo\x12\x1c.eolymp.oauth2.UserInfoInput\x1a\x1d.eolymp.oauth2.UserInfoOutput\"\x10\xea\xe2\n\x0c\xf5\xe2\n\x00\x00\xf0\x41\xf8\xe2\n\xac\x02\x12^\n\nIntrospect\x12\x1e.eolymp.oauth2.IntrospectInput\x1a\x1f.eolymp.oauth2.IntrospectOutput\"\x0f\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\n2\x12S\n\x06Revoke\x12\x1a.eolymp.oauth2.RevokeInput\x1a\x1b.eolymp.oauth2.RevokeOutput\"\x10\xea\xe2\n\x0c\xf5\xe2\n\x00\x00\xf0\x41\xf8\xe2\n\xac\x02\x12Y\n\x08\x41uthCode\x12\x1c.eolymp.oauth2.AuthCodeInput\x1a\x1d.eolymp.oauth2.AuthCodeOutput\"\x10\xea\xe2\n\x0c\xf5\xe2\n\x00\x00\xf0\x41\xf8\xe2\n\xac\x02\x12\\\n\tAuthorize\x12\x1d.eolymp.oauth2.AuthorizeInput\x1a\x1e.eolymp.oauth2.AuthorizeOutput\"\x10\xea\xe2\n\x0c\xf5\xe2\n\x00\x00\xf0\x41\xf8\xe2\n\xac\x02\x12Y\n\x08\x43\x61llback\x12\x1c.eolymp.oauth2.CallbackInput\x1a\x1d.eolymp.oauth2.CallbackOutput\"\x10\xea\xe2\n\x0c\xf5\xe2\n\x00\x00\xf0\x41\xf8\xe2\n\xac\x02\x42/Z-github.com/eolymp/go-sdk/eolymp/oauth2;oauth2b\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.oauth2.oauth2_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z-github.com/eolymp/go-sdk/eolymp/oauth2;oauth2'
  _OAUTH2.methods_by_name['Token']._options = None
  _OAUTH2.methods_by_name['Token']._serialized_options = b'\352\342\n\014\365\342\n\000\000\360A\370\342\n\254\002'
  _OAUTH2.methods_by_name['UserInfo']._options = None
  _OAUTH2.methods_by_name['UserInfo']._serialized_options = b'\352\342\n\014\365\342\n\000\000\360A\370\342\n\254\002'
  _OAUTH2.methods_by_name['Introspect']._options = None
  _OAUTH2.methods_by_name['Introspect']._serialized_options = b'\352\342\n\013\365\342\n\000\000 A\370\342\n2'
  _OAUTH2.methods_by_name['Revoke']._options = None
  _OAUTH2.methods_by_name['Revoke']._serialized_options = b'\352\342\n\014\365\342\n\000\000\360A\370\342\n\254\002'
  _OAUTH2.methods_by_name['AuthCode']._options = None
  _OAUTH2.methods_by_name['AuthCode']._serialized_options = b'\352\342\n\014\365\342\n\000\000\360A\370\342\n\254\002'
  _OAUTH2.methods_by_name['Authorize']._options = None
  _OAUTH2.methods_by_name['Authorize']._serialized_options = b'\352\342\n\014\365\342\n\000\000\360A\370\342\n\254\002'
  _OAUTH2.methods_by_name['Callback']._options = None
  _OAUTH2.methods_by_name['Callback']._serialized_options = b'\352\342\n\014\365\342\n\000\000\360A\370\342\n\254\002'
  _TOKENINPUT._serialized_start=115
  _TOKENINPUT._serialized_end=456
  _TOKENINPUT_GRANTTYPE._serialized_start=361
  _TOKENINPUT_GRANTTYPE._serialized_end=456
  _TOKENOUTPUT._serialized_start=459
  _TOKENOUTPUT._serialized_end=718
  _AUTHORIZEINPUT._serialized_start=721
  _AUTHORIZEINPUT._serialized_end=886
  _AUTHORIZEOUTPUT._serialized_start=888
  _AUTHORIZEOUTPUT._serialized_end=927
  _CALLBACKINPUT._serialized_start=929
  _CALLBACKINPUT._serialized_end=973
  _CALLBACKOUTPUT._serialized_start=975
  _CALLBACKOUTPUT._serialized_end=1013
  _USERINFOINPUT._serialized_start=1015
  _USERINFOINPUT._serialized_end=1030
  _USERINFOOUTPUT._serialized_start=1033
  _USERINFOOUTPUT._serialized_end=1265
  _INTROSPECTINPUT._serialized_start=1267
  _INTROSPECTINPUT._serialized_end=1299
  _INTROSPECTOUTPUT._serialized_start=1302
  _INTROSPECTOUTPUT._serialized_end=1550
  _AUTHCODEINPUT._serialized_start=1553
  _AUTHCODEINPUT._serialized_end=1717
  _AUTHCODEOUTPUT._serialized_start=1719
  _AUTHCODEOUTPUT._serialized_end=1785
  _REVOKEINPUT._serialized_start=1787
  _REVOKEINPUT._serialized_end=1815
  _REVOKEOUTPUT._serialized_start=1817
  _REVOKEOUTPUT._serialized_end=1831
  _OAUTH2._serialized_start=1834
  _OAUTH2._serialized_end=2472
# @@protoc_insertion_point(module_scope)



from eolymp.annotations import http_pb2 as _http_pb2
from eolymp.annotations import ratelimit_pb2 as _ratelimit_pb2
from eolymp.annotations import scope_pb2 as _scope_pb2
from eolymp.universe import permission_pb2 as _permission_pb2
from eolymp.universe import space_pb2 as _space_pb2
from eolymp.wellknown import expression_pb2 as _expression_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class CreateSpaceInput(_message.Message):
    __slots__ = ["space"]
    SPACE_FIELD_NUMBER: _ClassVar[int]
    space: _space_pb2.Space
    def __init__(self, space: _Optional[_Union[_space_pb2.Space, _Mapping]] = ...) -> None: ...

class CreateSpaceOutput(_message.Message):
    __slots__ = ["space_id"]
    SPACE_ID_FIELD_NUMBER: _ClassVar[int]
    space_id: str
    def __init__(self, space_id: _Optional[str] = ...) -> None: ...

class DeleteSpaceInput(_message.Message):
    __slots__ = ["space_id"]
    SPACE_ID_FIELD_NUMBER: _ClassVar[int]
    space_id: str
    def __init__(self, space_id: _Optional[str] = ...) -> None: ...

class DeleteSpaceOutput(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class DescribePermissionInput(_message.Message):
    __slots__ = ["space_id", "user_id"]
    SPACE_ID_FIELD_NUMBER: _ClassVar[int]
    USER_ID_FIELD_NUMBER: _ClassVar[int]
    space_id: str
    user_id: str
    def __init__(self, space_id: _Optional[str] = ..., user_id: _Optional[str] = ...) -> None: ...

class DescribePermissionOutput(_message.Message):
    __slots__ = ["permission"]
    PERMISSION_FIELD_NUMBER: _ClassVar[int]
    permission: _permission_pb2.Permission
    def __init__(self, permission: _Optional[_Union[_permission_pb2.Permission, _Mapping]] = ...) -> None: ...

class DescribeQuotaInput(_message.Message):
    __slots__ = ["space_id"]
    SPACE_ID_FIELD_NUMBER: _ClassVar[int]
    space_id: str
    def __init__(self, space_id: _Optional[str] = ...) -> None: ...

class DescribeQuotaOutput(_message.Message):
    __slots__ = ["quota"]
    QUOTA_FIELD_NUMBER: _ClassVar[int]
    quota: _space_pb2.Space.Quota
    def __init__(self, quota: _Optional[_Union[_space_pb2.Space.Quota, _Mapping]] = ...) -> None: ...

class DescribeSpaceInput(_message.Message):
    __slots__ = ["space_id"]
    SPACE_ID_FIELD_NUMBER: _ClassVar[int]
    space_id: str
    def __init__(self, space_id: _Optional[str] = ...) -> None: ...

class DescribeSpaceOutput(_message.Message):
    __slots__ = ["space"]
    SPACE_FIELD_NUMBER: _ClassVar[int]
    space: _space_pb2.Space
    def __init__(self, space: _Optional[_Union[_space_pb2.Space, _Mapping]] = ...) -> None: ...

class GrantPermissionInput(_message.Message):
    __slots__ = ["role", "space_id", "user_id"]
    ROLE_FIELD_NUMBER: _ClassVar[int]
    SPACE_ID_FIELD_NUMBER: _ClassVar[int]
    USER_ID_FIELD_NUMBER: _ClassVar[int]
    role: _permission_pb2.Permission.Role
    space_id: str
    user_id: str
    def __init__(self, space_id: _Optional[str] = ..., role: _Optional[_Union[_permission_pb2.Permission.Role, str]] = ..., user_id: _Optional[str] = ...) -> None: ...

class GrantPermissionOutput(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class IntrospectPermissionInput(_message.Message):
    __slots__ = ["space_id"]
    SPACE_ID_FIELD_NUMBER: _ClassVar[int]
    space_id: str
    def __init__(self, space_id: _Optional[str] = ...) -> None: ...

class IntrospectPermissionOutput(_message.Message):
    __slots__ = ["permission"]
    PERMISSION_FIELD_NUMBER: _ClassVar[int]
    permission: _permission_pb2.Permission
    def __init__(self, permission: _Optional[_Union[_permission_pb2.Permission, _Mapping]] = ...) -> None: ...

class ListPermissionsInput(_message.Message):
    __slots__ = ["filters", "offset", "size", "space_id"]
    class Filter(_message.Message):
        __slots__ = ["id", "role", "user_id"]
        ID_FIELD_NUMBER: _ClassVar[int]
        ROLE_FIELD_NUMBER: _ClassVar[int]
        USER_ID_FIELD_NUMBER: _ClassVar[int]
        id: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionID]
        role: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionEnum]
        user_id: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionID]
        def __init__(self, id: _Optional[_Iterable[_Union[_expression_pb2.ExpressionID, _Mapping]]] = ..., user_id: _Optional[_Iterable[_Union[_expression_pb2.ExpressionID, _Mapping]]] = ..., role: _Optional[_Iterable[_Union[_expression_pb2.ExpressionEnum, _Mapping]]] = ...) -> None: ...
    FILTERS_FIELD_NUMBER: _ClassVar[int]
    OFFSET_FIELD_NUMBER: _ClassVar[int]
    SIZE_FIELD_NUMBER: _ClassVar[int]
    SPACE_ID_FIELD_NUMBER: _ClassVar[int]
    filters: ListPermissionsInput.Filter
    offset: int
    size: int
    space_id: str
    def __init__(self, space_id: _Optional[str] = ..., offset: _Optional[int] = ..., size: _Optional[int] = ..., filters: _Optional[_Union[ListPermissionsInput.Filter, _Mapping]] = ...) -> None: ...

class ListPermissionsOutput(_message.Message):
    __slots__ = ["items", "total"]
    ITEMS_FIELD_NUMBER: _ClassVar[int]
    TOTAL_FIELD_NUMBER: _ClassVar[int]
    items: _containers.RepeatedCompositeFieldContainer[_permission_pb2.Permission]
    total: int
    def __init__(self, total: _Optional[int] = ..., items: _Optional[_Iterable[_Union[_permission_pb2.Permission, _Mapping]]] = ...) -> None: ...

class ListSpacesInput(_message.Message):
    __slots__ = ["filters", "offset", "size"]
    class Filter(_message.Message):
        __slots__ = ["id", "key", "name", "own", "query"]
        ID_FIELD_NUMBER: _ClassVar[int]
        KEY_FIELD_NUMBER: _ClassVar[int]
        NAME_FIELD_NUMBER: _ClassVar[int]
        OWN_FIELD_NUMBER: _ClassVar[int]
        QUERY_FIELD_NUMBER: _ClassVar[int]
        id: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionID]
        key: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionID]
        name: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionString]
        own: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionBool]
        query: str
        def __init__(self, query: _Optional[str] = ..., id: _Optional[_Iterable[_Union[_expression_pb2.ExpressionID, _Mapping]]] = ..., key: _Optional[_Iterable[_Union[_expression_pb2.ExpressionID, _Mapping]]] = ..., name: _Optional[_Iterable[_Union[_expression_pb2.ExpressionString, _Mapping]]] = ..., own: _Optional[_Iterable[_Union[_expression_pb2.ExpressionBool, _Mapping]]] = ...) -> None: ...
    FILTERS_FIELD_NUMBER: _ClassVar[int]
    OFFSET_FIELD_NUMBER: _ClassVar[int]
    SIZE_FIELD_NUMBER: _ClassVar[int]
    filters: ListSpacesInput.Filter
    offset: int
    size: int
    def __init__(self, offset: _Optional[int] = ..., size: _Optional[int] = ..., filters: _Optional[_Union[ListSpacesInput.Filter, _Mapping]] = ...) -> None: ...

class ListSpacesOutput(_message.Message):
    __slots__ = ["items", "total"]
    ITEMS_FIELD_NUMBER: _ClassVar[int]
    TOTAL_FIELD_NUMBER: _ClassVar[int]
    items: _containers.RepeatedCompositeFieldContainer[_space_pb2.Space]
    total: int
    def __init__(self, total: _Optional[int] = ..., items: _Optional[_Iterable[_Union[_space_pb2.Space, _Mapping]]] = ...) -> None: ...

class LookupSpaceInput(_message.Message):
    __slots__ = ["key"]
    KEY_FIELD_NUMBER: _ClassVar[int]
    key: str
    def __init__(self, key: _Optional[str] = ...) -> None: ...

class LookupSpaceOutput(_message.Message):
    __slots__ = ["space"]
    SPACE_FIELD_NUMBER: _ClassVar[int]
    space: _space_pb2.Space
    def __init__(self, space: _Optional[_Union[_space_pb2.Space, _Mapping]] = ...) -> None: ...

class RevokePermissionInput(_message.Message):
    __slots__ = ["space_id", "user_id"]
    SPACE_ID_FIELD_NUMBER: _ClassVar[int]
    USER_ID_FIELD_NUMBER: _ClassVar[int]
    space_id: str
    user_id: str
    def __init__(self, space_id: _Optional[str] = ..., user_id: _Optional[str] = ...) -> None: ...

class RevokePermissionOutput(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class UpdateQuotaInput(_message.Message):
    __slots__ = ["quota", "space_id"]
    QUOTA_FIELD_NUMBER: _ClassVar[int]
    SPACE_ID_FIELD_NUMBER: _ClassVar[int]
    quota: _space_pb2.Space.Quota
    space_id: str
    def __init__(self, space_id: _Optional[str] = ..., quota: _Optional[_Union[_space_pb2.Space.Quota, _Mapping]] = ...) -> None: ...

class UpdateQuotaOutput(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class UpdateSpaceInput(_message.Message):
    __slots__ = ["patch", "space", "space_id"]
    class Patch(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = []
    ALL: UpdateSpaceInput.Patch
    IMAGE: UpdateSpaceInput.Patch
    KEY: UpdateSpaceInput.Patch
    NAME: UpdateSpaceInput.Patch
    PATCH_FIELD_NUMBER: _ClassVar[int]
    SPACE_FIELD_NUMBER: _ClassVar[int]
    SPACE_ID_FIELD_NUMBER: _ClassVar[int]
    TYPE: UpdateSpaceInput.Patch
    VISIBILITY: UpdateSpaceInput.Patch
    patch: _containers.RepeatedScalarFieldContainer[UpdateSpaceInput.Patch]
    space: _space_pb2.Space
    space_id: str
    def __init__(self, patch: _Optional[_Iterable[_Union[UpdateSpaceInput.Patch, str]]] = ..., space_id: _Optional[str] = ..., space: _Optional[_Union[_space_pb2.Space, _Mapping]] = ...) -> None: ...

class UpdateSpaceOutput(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...



from eolymp.community import configuration_idp_pb2 as _configuration_idp_pb2
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class IdentityConfig(_message.Message):
    __slots__ = ["basecamp", "display_name_attribute", "display_name_type", "local", "oidc"]
    class DisplayNameType(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = []
    ATTRIBUTE: IdentityConfig.DisplayNameType
    BASECAMP_FIELD_NUMBER: _ClassVar[int]
    DISPLAY_NAME_ATTRIBUTE_FIELD_NUMBER: _ClassVar[int]
    DISPLAY_NAME_TYPE_FIELD_NUMBER: _ClassVar[int]
    LOCAL_FIELD_NUMBER: _ClassVar[int]
    NAME: IdentityConfig.DisplayNameType
    NICKNAME: IdentityConfig.DisplayNameType
    OIDC_FIELD_NUMBER: _ClassVar[int]
    UNKNOWN_DISPLAY_NAME: IdentityConfig.DisplayNameType
    basecamp: _configuration_idp_pb2.IdentityProvider.Basecamp
    display_name_attribute: str
    display_name_type: IdentityConfig.DisplayNameType
    local: _configuration_idp_pb2.IdentityProvider.Local
    oidc: _configuration_idp_pb2.IdentityProvider.OIDC
    def __init__(self, local: _Optional[_Union[_configuration_idp_pb2.IdentityProvider.Local, _Mapping]] = ..., basecamp: _Optional[_Union[_configuration_idp_pb2.IdentityProvider.Basecamp, _Mapping]] = ..., oidc: _Optional[_Union[_configuration_idp_pb2.IdentityProvider.OIDC, _Mapping]] = ..., display_name_type: _Optional[_Union[IdentityConfig.DisplayNameType, str]] = ..., display_name_attribute: _Optional[str] = ...) -> None: ...



from eolymp.course import entry_problem_pb2 as _entry_problem_pb2
from eolymp.course import entry_section_pb2 as _entry_section_pb2
from eolymp.course import entry_video_pb2 as _entry_video_pb2
from eolymp.ecm import content_pb2 as _content_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Entry(_message.Message):
    __slots__ = ["document", "draft", "estimate", "id", "index", "items", "parent_id", "problem", "section", "title", "url", "video"]
    DOCUMENT_FIELD_NUMBER: _ClassVar[int]
    DRAFT_FIELD_NUMBER: _ClassVar[int]
    ESTIMATE_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    INDEX_FIELD_NUMBER: _ClassVar[int]
    ITEMS_FIELD_NUMBER: _ClassVar[int]
    PARENT_ID_FIELD_NUMBER: _ClassVar[int]
    PROBLEM_FIELD_NUMBER: _ClassVar[int]
    SECTION_FIELD_NUMBER: _ClassVar[int]
    TITLE_FIELD_NUMBER: _ClassVar[int]
    URL_FIELD_NUMBER: _ClassVar[int]
    VIDEO_FIELD_NUMBER: _ClassVar[int]
    document: _content_pb2.Content
    draft: bool
    estimate: int
    id: str
    index: int
    items: _containers.RepeatedCompositeFieldContainer[Entry]
    parent_id: str
    problem: _entry_problem_pb2.Problem
    section: _entry_section_pb2.Section
    title: str
    url: str
    video: _entry_video_pb2.Video
    def __init__(self, id: _Optional[str] = ..., url: _Optional[str] = ..., title: _Optional[str] = ..., draft: bool = ..., parent_id: _Optional[str] = ..., index: _Optional[int] = ..., estimate: _Optional[int] = ..., section: _Optional[_Union[_entry_section_pb2.Section, _Mapping]] = ..., document: _Optional[_Union[_content_pb2.Content, _Mapping]] = ..., video: _Optional[_Union[_entry_video_pb2.Video, _Mapping]] = ..., problem: _Optional[_Union[_entry_problem_pb2.Problem, _Mapping]] = ..., items: _Optional[_Iterable[_Union[Entry, _Mapping]]] = ...) -> None: ...



from eolymp.discussion import message_pb2 as _message_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class MessageChangedEvent(_message.Message):
    __slots__ = ["after", "before"]
    AFTER_FIELD_NUMBER: _ClassVar[int]
    BEFORE_FIELD_NUMBER: _ClassVar[int]
    after: _message_pb2.Message
    before: _message_pb2.Message
    def __init__(self, before: _Optional[_Union[_message_pb2.Message, _Mapping]] = ..., after: _Optional[_Union[_message_pb2.Message, _Mapping]] = ...) -> None: ...



from eolymp.annotations import http_pb2 as _http_pb2
from eolymp.annotations import ratelimit_pb2 as _ratelimit_pb2
from eolymp.annotations import scope_pb2 as _scope_pb2
from eolymp.atlas import attachment_service_pb2 as _attachment_service_pb2
from eolymp.atlas import bookmark_service_pb2 as _bookmark_service_pb2
from eolymp.atlas import code_template_service_pb2 as _code_template_service_pb2
from eolymp.atlas import library_service_pb2 as _library_service_pb2
from eolymp.atlas import problem_service_pb2 as _problem_service_pb2
from eolymp.atlas import scoring_service_pb2 as _scoring_service_pb2
from eolymp.atlas import statement_service_pb2 as _statement_service_pb2
from eolymp.atlas import submission_service_pb2 as _submission_service_pb2
from eolymp.atlas import testing_service_pb2 as _testing_service_pb2
from google.protobuf import descriptor as _descriptor
from typing import ClassVar as _ClassVar

DESCRIPTOR: _descriptor.FileDescriptor



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/universe/space.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1b\x65olymp/universe/space.proto\x12\x0f\x65olymp.universe\"\xa9\x05\n\x05Space\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0b\n\x03key\x18\x02 \x01(\t\x12\x0b\n\x03url\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\n \x01(\t\x12\r\n\x05image\x18\x0b \x01(\t\x12)\n\x04type\x18\x0c \x01(\x0e\x32\x1b.eolymp.universe.Space.Type\x12\x0c\n\x04plan\x18\r \x01(\t\x12\x35\n\nvisibility\x18\x0e \x01(\x0e\x32!.eolymp.universe.Space.Visibility\x12\x10\n\x08home_url\x18\x32 \x01(\t\x12\x12\n\nissuer_url\x18\x33 \x01(\t\x1a\xb4\x02\n\x05Quota\x12\x1a\n\x12problems_per_space\x18\x01 \x01(\r\x12\x19\n\x11members_per_space\x18\x02 \x01(\r\x12\x1a\n\x12\x63ontests_per_space\x18\x03 \x01(\r\x12!\n\x19\x61\x63tive_contests_per_space\x18\x04 \x01(\r\x12\x1d\n\x15scoreboards_per_space\x18\x05 \x01(\r\x12\x1d\n\x15permissions_per_space\x18\x06 \x01(\r\x12\x1c\n\x14\x61ttributes_per_space\x18\x07 \x01(\r\x12\x19\n\x11\x63ourses_per_space\x18\x0c \x01(\r\x12\x1c\n\x14problems_per_contest\x18\n \x01(\r\x12 \n\x18participants_per_contest\x18\x0b \x01(\r\"Q\n\x04Type\x12\x10\n\x0cUNKNOWN_TYPE\x10\x00\x12\t\n\x05OTHER\x10\x01\x12\r\n\tCLASSROOM\x10\x02\x12\x0c\n\x08TEAMROOM\x10\x03\x12\x0f\n\x0b\x43OMPETITION\x10\x04\"=\n\nVisibility\x12\x16\n\x12UNKNOWN_VISIBILITY\x10\x00\x12\n\n\x06PUBLIC\x10\x01\x12\x0b\n\x07PRIVATE\x10\x02\x42\x33Z1github.com/eolymp/go-sdk/eolymp/universe;universeb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.universe.space_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z1github.com/eolymp/go-sdk/eolymp/universe;universe'
  _SPACE._serialized_start=49
  _SPACE._serialized_end=730
  _SPACE_QUOTA._serialized_start=276
  _SPACE_QUOTA._serialized_end=584
  _SPACE_TYPE._serialized_start=586
  _SPACE_TYPE._serialized_end=667
  _SPACE_VISIBILITY._serialized_start=669
  _SPACE_VISIBILITY._serialized_end=730
# @@protoc_insertion_point(module_scope)



from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Subscription(_message.Message):
    __slots__ = ["cancel_url", "cancellation_comment", "cancellation_feedback", "cancellation_reason", "cancelled_at", "checkout_url", "created_at", "currency", "id", "items", "member_id", "payer_email", "payment_method", "period_end", "period_start", "space_id", "started_at", "status", "success_url", "total_amount", "user_id"]
    class Status(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = []
    class Item(_message.Message):
        __slots__ = ["active", "id", "price_id", "product_id"]
        ACTIVE_FIELD_NUMBER: _ClassVar[int]
        ID_FIELD_NUMBER: _ClassVar[int]
        PRICE_ID_FIELD_NUMBER: _ClassVar[int]
        PRODUCT_ID_FIELD_NUMBER: _ClassVar[int]
        active: bool
        id: str
        price_id: str
        product_id: str
        def __init__(self, id: _Optional[str] = ..., active: bool = ..., product_id: _Optional[str] = ..., price_id: _Optional[str] = ...) -> None: ...
    ACTIVE: Subscription.Status
    CANCELLATION_COMMENT_FIELD_NUMBER: _ClassVar[int]
    CANCELLATION_FEEDBACK_FIELD_NUMBER: _ClassVar[int]
    CANCELLATION_REASON_FIELD_NUMBER: _ClassVar[int]
    CANCELLED: Subscription.Status
    CANCELLED_AT_FIELD_NUMBER: _ClassVar[int]
    CANCEL_URL_FIELD_NUMBER: _ClassVar[int]
    CHECKOUT_URL_FIELD_NUMBER: _ClassVar[int]
    CREATED_AT_FIELD_NUMBER: _ClassVar[int]
    CURRENCY_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    ITEMS_FIELD_NUMBER: _ClassVar[int]
    MEMBER_ID_FIELD_NUMBER: _ClassVar[int]
    PAUSED: Subscription.Status
    PAYER_EMAIL_FIELD_NUMBER: _ClassVar[int]
    PAYMENT_METHOD_FIELD_NUMBER: _ClassVar[int]
    PENDING: Subscription.Status
    PERIOD_END_FIELD_NUMBER: _ClassVar[int]
    PERIOD_START_FIELD_NUMBER: _ClassVar[int]
    SPACE_ID_FIELD_NUMBER: _ClassVar[int]
    STARTED_AT_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    SUCCESS_URL_FIELD_NUMBER: _ClassVar[int]
    TOTAL_AMOUNT_FIELD_NUMBER: _ClassVar[int]
    UNKNOWN_STATUS: Subscription.Status
    USER_ID_FIELD_NUMBER: _ClassVar[int]
    cancel_url: str
    cancellation_comment: str
    cancellation_feedback: str
    cancellation_reason: str
    cancelled_at: _timestamp_pb2.Timestamp
    checkout_url: str
    created_at: _timestamp_pb2.Timestamp
    currency: str
    id: str
    items: _containers.RepeatedCompositeFieldContainer[Subscription.Item]
    member_id: str
    payer_email: str
    payment_method: str
    period_end: _timestamp_pb2.Timestamp
    period_start: _timestamp_pb2.Timestamp
    space_id: str
    started_at: _timestamp_pb2.Timestamp
    status: Subscription.Status
    success_url: str
    total_amount: int
    user_id: str
    def __init__(self, id: _Optional[str] = ..., status: _Optional[_Union[Subscription.Status, str]] = ..., space_id: _Optional[str] = ..., user_id: _Optional[str] = ..., member_id: _Optional[str] = ..., payer_email: _Optional[str] = ..., created_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., started_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., cancelled_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., period_start: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., period_end: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., payment_method: _Optional[str] = ..., cancellation_comment: _Optional[str] = ..., cancellation_feedback: _Optional[str] = ..., cancellation_reason: _Optional[str] = ..., currency: _Optional[str] = ..., total_amount: _Optional[int] = ..., success_url: _Optional[str] = ..., cancel_url: _Optional[str] = ..., checkout_url: _Optional[str] = ..., items: _Optional[_Iterable[_Union[Subscription.Item, _Mapping]]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/community/subscription.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#eolymp/community/subscription.proto\x12\x10\x65olymp.community\x1a\x1fgoogle/protobuf/timestamp.proto\"\xa6\x05\n\x0cSubscription\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0f\n\x07tier_id\x18\x02 \x01(\t\x12\x11\n\tmember_id\x18\x03 \x01(\t\x12.\n\ncreated_at\x18\n \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nstarted_at\x18\x0b \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nrenewed_at\x18\x0c \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12-\n\trenews_at\x18\r \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x30\n\x0c\x63\x61ncelled_at\x18\x0e \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12-\n\tpaused_at\x18\x0f \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x16\n\x0epayment_method\x18\x14 \x01(\t\x12=\n\nrecurrence\x18\x1e \x01(\x0e\x32).eolymp.community.Subscription.Recurrence\x12\x10\n\x08\x63urrency\x18\x1f \x01(\t\x12\x0e\n\x06\x61mount\x18  \x01(\r\x12\x10\n\x08tax_name\x18) \x01(\t\x12\x12\n\ntax_amount\x18* \x01(\r\x12\x16\n\x0etax_percentage\x18+ \x01(\r\"=\n\nRecurrence\x12\x16\n\x12UNKNOWN_RECURRENCE\x10\x00\x12\x0b\n\x07MONTHLY\x10\x01\x12\n\n\x06YEARLY\x10\x02\"P\n\x06Status\x12\x12\n\x0eUNKNOWN_STATUS\x10\x00\x12\x0b\n\x07PENDING\x10\x01\x12\n\n\x06\x41\x43TIVE\x10\x02\x12\n\n\x06PAUSED\x10\x03\x12\r\n\tCANCELLED\x10\x04\x42\x35Z3github.com/eolymp/go-sdk/eolymp/community;communityb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.community.subscription_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z3github.com/eolymp/go-sdk/eolymp/community;community'
  _SUBSCRIPTION._serialized_start=91
  _SUBSCRIPTION._serialized_end=769
  _SUBSCRIPTION_RECURRENCE._serialized_start=626
  _SUBSCRIPTION_RECURRENCE._serialized_end=687
  _SUBSCRIPTION_STATUS._serialized_start=689
  _SUBSCRIPTION_STATUS._serialized_end=769
# @@protoc_insertion_point(module_scope)



from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Subscription(_message.Message):
    __slots__ = ["amount", "cancelled_at", "created_at", "currency", "id", "member_id", "paused_at", "payment_method", "recurrence", "renewed_at", "renews_at", "started_at", "tax_amount", "tax_name", "tax_percentage", "tier_id"]
    class Recurrence(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = []
    class Status(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = []
    ACTIVE: Subscription.Status
    AMOUNT_FIELD_NUMBER: _ClassVar[int]
    CANCELLED: Subscription.Status
    CANCELLED_AT_FIELD_NUMBER: _ClassVar[int]
    CREATED_AT_FIELD_NUMBER: _ClassVar[int]
    CURRENCY_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    MEMBER_ID_FIELD_NUMBER: _ClassVar[int]
    MONTHLY: Subscription.Recurrence
    PAUSED: Subscription.Status
    PAUSED_AT_FIELD_NUMBER: _ClassVar[int]
    PAYMENT_METHOD_FIELD_NUMBER: _ClassVar[int]
    PENDING: Subscription.Status
    RECURRENCE_FIELD_NUMBER: _ClassVar[int]
    RENEWED_AT_FIELD_NUMBER: _ClassVar[int]
    RENEWS_AT_FIELD_NUMBER: _ClassVar[int]
    STARTED_AT_FIELD_NUMBER: _ClassVar[int]
    TAX_AMOUNT_FIELD_NUMBER: _ClassVar[int]
    TAX_NAME_FIELD_NUMBER: _ClassVar[int]
    TAX_PERCENTAGE_FIELD_NUMBER: _ClassVar[int]
    TIER_ID_FIELD_NUMBER: _ClassVar[int]
    UNKNOWN_RECURRENCE: Subscription.Recurrence
    UNKNOWN_STATUS: Subscription.Status
    YEARLY: Subscription.Recurrence
    amount: int
    cancelled_at: _timestamp_pb2.Timestamp
    created_at: _timestamp_pb2.Timestamp
    currency: str
    id: str
    member_id: str
    paused_at: _timestamp_pb2.Timestamp
    payment_method: str
    recurrence: Subscription.Recurrence
    renewed_at: _timestamp_pb2.Timestamp
    renews_at: _timestamp_pb2.Timestamp
    started_at: _timestamp_pb2.Timestamp
    tax_amount: int
    tax_name: str
    tax_percentage: int
    tier_id: str
    def __init__(self, id: _Optional[str] = ..., tier_id: _Optional[str] = ..., member_id: _Optional[str] = ..., created_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., started_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., renewed_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., renews_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., cancelled_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., paused_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., payment_method: _Optional[str] = ..., recurrence: _Optional[_Union[Subscription.Recurrence, str]] = ..., currency: _Optional[str] = ..., amount: _Optional[int] = ..., tax_name: _Optional[str] = ..., tax_amount: _Optional[int] = ..., tax_percentage: _Optional[int] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/commerce/subscription.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"eolymp/commerce/subscription.proto\x12\x0f\x65olymp.commerce\x1a\x1fgoogle/protobuf/timestamp.proto\"\xc5\x06\n\x0cSubscription\x12\n\n\x02id\x18\x01 \x01(\t\x12\x34\n\x06status\x18\x02 \x01(\x0e\x32$.eolymp.commerce.Subscription.Status\x12\x10\n\x08space_id\x18\x03 \x01(\t\x12\x11\n\x07user_id\x18\x05 \x01(\tH\x00\x12\x13\n\tmember_id\x18\x06 \x01(\tH\x00\x12\x13\n\x0bpayer_email\x18\x07 \x01(\t\x12.\n\ncreated_at\x18\n \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nstarted_at\x18\x0b \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x30\n\x0c\x63\x61ncelled_at\x18\x0c \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x30\n\x0cperiod_start\x18( \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nperiod_end\x18) \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x16\n\x0epayment_method\x18\x14 \x01(\t\x12\x1c\n\x14\x63\x61ncellation_comment\x18\x32 \x01(\t\x12\x1d\n\x15\x63\x61ncellation_feedback\x18\x33 \x01(\t\x12\x1b\n\x13\x63\x61ncellation_reason\x18\x34 \x01(\t\x12\x10\n\x08\x63urrency\x18\x1f \x01(\t\x12\x14\n\x0ctotal_amount\x18  \x01(\r\x12\x13\n\x0bsuccess_url\x18< \x01(\t\x12\x12\n\ncancel_url\x18= \x01(\t\x12\x14\n\x0c\x63heckout_url\x18> \x01(\t\x12\x32\n\x05items\x18\xe7\x07 \x03(\x0b\x32\".eolymp.commerce.Subscription.Item\x1aH\n\x04Item\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0e\n\x06\x61\x63tive\x18\x02 \x01(\x08\x12\x12\n\nproduct_id\x18\x14 \x01(\t\x12\x10\n\x08price_id\x18\x15 \x01(\t\"P\n\x06Status\x12\x12\n\x0eUNKNOWN_STATUS\x10\x00\x12\x0b\n\x07PENDING\x10\x01\x12\n\n\x06\x41\x43TIVE\x10\x02\x12\n\n\x06PAUSED\x10\x03\x12\r\n\tCANCELLED\x10\x04\x42\x07\n\x05payerB3Z1github.com/eolymp/go-sdk/eolymp/commerce;commerceb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.commerce.subscription_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z1github.com/eolymp/go-sdk/eolymp/commerce;commerce'
  _SUBSCRIPTION._serialized_start=89
  _SUBSCRIPTION._serialized_end=926
  _SUBSCRIPTION_ITEM._serialized_start=763
  _SUBSCRIPTION_ITEM._serialized_end=835
  _SUBSCRIPTION_STATUS._serialized_start=837
  _SUBSCRIPTION_STATUS._serialized_end=917
# @@protoc_insertion_point(module_scope)



from eolymp.annotations import http_pb2 as _http_pb2
from eolymp.annotations import ratelimit_pb2 as _ratelimit_pb2
from eolymp.annotations import scope_pb2 as _scope_pb2
from eolymp.community import subscription_pb2 as _subscription_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class DescribeSubscriptionInput(_message.Message):
    __slots__ = ["subscription_id"]
    SUBSCRIPTION_ID_FIELD_NUMBER: _ClassVar[int]
    subscription_id: str
    def __init__(self, subscription_id: _Optional[str] = ...) -> None: ...

class DescribeSubscriptionOutput(_message.Message):
    __slots__ = ["subscription"]
    SUBSCRIPTION_FIELD_NUMBER: _ClassVar[int]
    subscription: _subscription_pb2.Subscription
    def __init__(self, subscription: _Optional[_Union[_subscription_pb2.Subscription, _Mapping]] = ...) -> None: ...

class ListSubscriptionsInput(_message.Message):
    __slots__ = ["offset", "size"]
    OFFSET_FIELD_NUMBER: _ClassVar[int]
    SIZE_FIELD_NUMBER: _ClassVar[int]
    offset: int
    size: int
    def __init__(self, offset: _Optional[int] = ..., size: _Optional[int] = ...) -> None: ...

class ListSubscriptionsOutput(_message.Message):
    __slots__ = ["items", "total"]
    ITEMS_FIELD_NUMBER: _ClassVar[int]
    TOTAL_FIELD_NUMBER: _ClassVar[int]
    items: _containers.RepeatedCompositeFieldContainer[_subscription_pb2.Subscription]
    total: int
    def __init__(self, total: _Optional[int] = ..., items: _Optional[_Iterable[_Union[_subscription_pb2.Subscription, _Mapping]]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/discussion/discussion.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.ecm import content_pb2 as eolymp_dot_ecm_dot_content__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"eolymp/discussion/discussion.proto\x12\x11\x65olymp.discussion\x1a\x18\x65olymp/ecm/content.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xe1\x02\n\nDiscussion\x12\n\n\x02id\x18\x01 \x01(\t\x12\x11\n\tmember_id\x18\x03 \x01(\t\x12\x0c\n\x03url\x18\xaa\x05 \x01(\t\x12\x38\n\x05links\x18\xab\x05 \x03(\x0b\x32(.eolymp.discussion.Discussion.LinksEntry\x12\x12\n\nvote_count\x18\n \x01(\x05\x12\x13\n\x0breply_count\x18\x0b \x01(\x05\x12.\n\ncreated_at\x18\x14 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nupdated_at\x18\x15 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0f\n\x07subject\x18\x64 \x01(\t\x12$\n\x07message\x18\x65 \x01(\x0b\x32\x13.eolymp.ecm.Content\x1a,\n\nLinksEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\x37Z5github.com/eolymp/go-sdk/eolymp/discussion;discussionb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.discussion.discussion_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z5github.com/eolymp/go-sdk/eolymp/discussion;discussion'
  _DISCUSSION_LINKSENTRY._options = None
  _DISCUSSION_LINKSENTRY._serialized_options = b'8\001'
  _DISCUSSION._serialized_start=117
  _DISCUSSION._serialized_end=470
  _DISCUSSION_LINKSENTRY._serialized_start=426
  _DISCUSSION_LINKSENTRY._serialized_end=470
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/commerce/product.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.commerce import price_pb2 as eolymp_dot_commerce_dot_price__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1d\x65olymp/commerce/product.proto\x12\x0f\x65olymp.commerce\x1a\x1b\x65olymp/commerce/price.proto\"\xac\x01\n\x07Product\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0e\n\x06\x61\x63tive\x18\x02 \x01(\x08\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\r\n\x05image\x18\x04 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x05 \x01(\t\x12\x10\n\x08page_url\x18\x06 \x01(\t\x12\x12\n\nunit_label\x18\x07 \x01(\t\x12-\n\rdefault_price\x18\n \x01(\x0b\x32\x16.eolymp.commerce.PriceB3Z1github.com/eolymp/go-sdk/eolymp/commerce;commerceb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.commerce.product_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z1github.com/eolymp/go-sdk/eolymp/commerce;commerce'
  _PRODUCT._serialized_start=80
  _PRODUCT._serialized_end=252
# @@protoc_insertion_point(module_scope)



from eolymp.commerce import subscription_pb2 as _subscription_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class SubscriptionChangedEvent(_message.Message):
    __slots__ = ["after", "before"]
    AFTER_FIELD_NUMBER: _ClassVar[int]
    BEFORE_FIELD_NUMBER: _ClassVar[int]
    after: _subscription_pb2.Subscription
    before: _subscription_pb2.Subscription
    def __init__(self, before: _Optional[_Union[_subscription_pb2.Subscription, _Mapping]] = ..., after: _Optional[_Union[_subscription_pb2.Subscription, _Mapping]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/discussion/events.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.discussion import message_pb2 as eolymp_dot_discussion_dot_message__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1e\x65olymp/discussion/events.proto\x12\x11\x65olymp.discussion\x1a\x1f\x65olymp/discussion/message.proto\"l\n\x13MessageChangedEvent\x12*\n\x06\x62\x65\x66ore\x18\x01 \x01(\x0b\x32\x1a.eolymp.discussion.Message\x12)\n\x05\x61\x66ter\x18\x02 \x01(\x0b\x32\x1a.eolymp.discussion.MessageB7Z5github.com/eolymp/go-sdk/eolymp/discussion;discussionb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.discussion.events_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z5github.com/eolymp/go-sdk/eolymp/discussion;discussion'
  _MESSAGECHANGEDEVENT._serialized_start=86
  _MESSAGECHANGEDEVENT._serialized_end=194
# @@protoc_insertion_point(module_scope)



from google.protobuf import descriptor_pb2 as _descriptor_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor
RATELIMIT_FIELD_NUMBER: _ClassVar[int]
ratelimit: _descriptor.FieldDescriptor

class RateLimit(_message.Message):
    __slots__ = ["burst", "limit"]
    BURST_FIELD_NUMBER: _ClassVar[int]
    LIMIT_FIELD_NUMBER: _ClassVar[int]
    burst: int
    limit: float
    def __init__(self, limit: _Optional[float] = ..., burst: _Optional[int] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/community/tier_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.annotations import scope_pb2 as eolymp_dot_annotations_dot_scope__pb2
from eolymp.commerce import price_pb2 as eolymp_dot_commerce_dot_price__pb2
from eolymp.community import tier_pb2 as eolymp_dot_community_dot_tier__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#eolymp/community/tier_service.proto\x12\x10\x65olymp.community\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a\x1e\x65olymp/annotations/scope.proto\x1a\x1b\x65olymp/commerce/price.proto\x1a\x1b\x65olymp/community/tier.proto\"N\n\x0eListTiersInput\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\x12\x0e\n\x06render\x18\x64 \x01(\x08\x12\x0e\n\x06locale\x18\x65 \x01(\t\"G\n\x0fListTiersOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12%\n\x05items\x18\x02 \x03(\x0b\x32\x16.eolymp.community.Tier\"D\n\x11\x44\x65scribeTierInput\x12\x0f\n\x07tier_id\x18\x01 \x01(\t\x12\x0e\n\x06render\x18\x64 \x01(\x08\x12\x0e\n\x06locale\x18\x65 \x01(\t\":\n\x12\x44\x65scribeTierOutput\x12$\n\x04tier\x18\x01 \x01(\x0b\x32\x16.eolymp.community.Tier\"8\n\x13ListTierPricesInput\x12\x0f\n\x07tier_id\x18\x01 \x01(\t\x12\x10\n\x08\x63urrency\x18\x02 \x01(\t\"=\n\x14ListTierPricesOutput\x12%\n\x05items\x18\x01 \x03(\x0b\x32\x16.eolymp.commerce.Price2\xcc\x03\n\x0bTierService\x12\x9d\x01\n\x0c\x44\x65scribeTier\x12#.eolymp.community.DescribeTierInput\x1a$.eolymp.community.DescribeTierOutput\"B\x82\xe3\n\x17\x8a\xe3\n\x13\x63ommunity:tier:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x82\xd3\xe4\x93\x02\x12\x12\x10/tiers/{tier_id}\x12\x8a\x01\n\tListTiers\x12 .eolymp.community.ListTiersInput\x1a!.eolymp.community.ListTiersOutput\"8\x82\xe3\n\x17\x8a\xe3\n\x13\x63ommunity:tier:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02\x08\x12\x06/tiers\x12\x8f\x01\n\x0eListTierPrices\x12%.eolymp.community.ListTierPricesInput\x1a&.eolymp.community.ListTierPricesOutput\".\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02\x19\x12\x17/tiers/{tier_id}/pricesB5Z3github.com/eolymp/go-sdk/eolymp/community;communityb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.community.tier_service_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z3github.com/eolymp/go-sdk/eolymp/community;community'
  _TIERSERVICE.methods_by_name['DescribeTier']._options = None
  _TIERSERVICE.methods_by_name['DescribeTier']._serialized_options = b'\202\343\n\027\212\343\n\023community:tier:read\352\342\n\013\365\342\n\000\000\240@\370\342\n2\202\323\344\223\002\022\022\020/tiers/{tier_id}'
  _TIERSERVICE.methods_by_name['ListTiers']._options = None
  _TIERSERVICE.methods_by_name['ListTiers']._serialized_options = b'\202\343\n\027\212\343\n\023community:tier:read\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\323\344\223\002\010\022\006/tiers'
  _TIERSERVICE.methods_by_name['ListTierPrices']._options = None
  _TIERSERVICE.methods_by_name['ListTierPrices']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\323\344\223\002\031\022\027/tiers/{tier_id}/prices'
  _LISTTIERSINPUT._serialized_start=214
  _LISTTIERSINPUT._serialized_end=292
  _LISTTIERSOUTPUT._serialized_start=294
  _LISTTIERSOUTPUT._serialized_end=365
  _DESCRIBETIERINPUT._serialized_start=367
  _DESCRIBETIERINPUT._serialized_end=435
  _DESCRIBETIEROUTPUT._serialized_start=437
  _DESCRIBETIEROUTPUT._serialized_end=495
  _LISTTIERPRICESINPUT._serialized_start=497
  _LISTTIERPRICESINPUT._serialized_end=553
  _LISTTIERPRICESOUTPUT._serialized_start=555
  _LISTTIERPRICESOUTPUT._serialized_end=616
  _TIERSERVICE._serialized_start=619
  _TIERSERVICE._serialized_end=1079
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler. DO NOT EDIT!
# See https://github.com/eolymp/contracts/tree/main/cmd/protoc-gen-python-esdk for more details.
"""Generated protocol buffer code."""

import urllib.parse
from google.protobuf import symbol_database as _symbol_database

_sym_db = _symbol_database.Default()


class LocalizationServiceClient:
    def __init__(self, transport, url="https://api.eolymp.com"):
        self.transport = transport
        self.url = url

    def CreateTerm(self, request, **kwargs):
        path = "/terms"

        return self.transport.request(
            method="POST",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.l10n.CreateTermOutput"),
            **kwargs,
        )

    def ListTerms(self, request, **kwargs):
        path = "/terms"

        return self.transport.request(
            method="GET",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.l10n.ListTermsOutput"),
            **kwargs,
        )

    def UpdateTerm(self, request, **kwargs):
        path = "/terms/"+urllib.parse.quote(request.term_id)

        # Cleanup URL parameters to avoid any ambiguity
        request.term_id = ""

        return self.transport.request(
            method="PUT",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.l10n.UpdateTermOutput"),
            **kwargs,
        )

    def RestoreTerm(self, request, **kwargs):
        path = "/terms/"+urllib.parse.quote(request.term_id)+"/restore"

        # Cleanup URL parameters to avoid any ambiguity
        request.term_id = ""

        return self.transport.request(
            method="POST",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.l10n.RestoreTermOutput"),
            **kwargs,
        )

    def DeprecateTerm(self, request, **kwargs):
        path = "/terms/"+urllib.parse.quote(request.term_id)+"/deprecate"

        # Cleanup URL parameters to avoid any ambiguity
        request.term_id = ""

        return self.transport.request(
            method="POST",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.l10n.DeprecateTermOutput"),
            **kwargs,
        )

    def DeleteTerm(self, request, **kwargs):
        path = "/terms/"+urllib.parse.quote(request.term_id)

        # Cleanup URL parameters to avoid any ambiguity
        request.term_id = ""

        return self.transport.request(
            method="DELETE",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.l10n.DeleteTermOutput"),
            **kwargs,
        )

    def DescribeTerm(self, request, **kwargs):
        path = "/terms/"+urllib.parse.quote(request.term_id)

        # Cleanup URL parameters to avoid any ambiguity
        request.term_id = ""

        return self.transport.request(
            method="GET",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.l10n.DescribeTermOutput"),
            **kwargs,
        )

    def ImportTerms(self, request, **kwargs):
        path = "/terms"

        return self.transport.request(
            method="PUT",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.l10n.ImportTermsOutput"),
            **kwargs,
        )

    def AddLocale(self, request, **kwargs):
        path = "/locales/"+urllib.parse.quote(request.locale_code)

        # Cleanup URL parameters to avoid any ambiguity
        request.locale_code = ""

        return self.transport.request(
            method="PUT",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.l10n.AddLocaleOutput"),
            **kwargs,
        )

    def RemoveLocale(self, request, **kwargs):
        path = "/locales/"+urllib.parse.quote(request.locale_code)

        # Cleanup URL parameters to avoid any ambiguity
        request.locale_code = ""

        return self.transport.request(
            method="DELETE",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.l10n.RemoveLocaleOutput"),
            **kwargs,
        )

    def ListLocales(self, request, **kwargs):
        path = "/locales"

        return self.transport.request(
            method="GET",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.l10n.ListLocalesOutput"),
            **kwargs,
        )

    def TranslateTerm(self, request, **kwargs):
        path = "/terms/"+urllib.parse.quote(request.term_id)+"/translations"

        # Cleanup URL parameters to avoid any ambiguity
        request.term_id = ""

        return self.transport.request(
            method="POST",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.l10n.TranslateTermOutput"),
            **kwargs,
        )

    def ListTranslations(self, request, **kwargs):
        path = "/terms/"+urllib.parse.quote(request.term_id)+"/translations"

        # Cleanup URL parameters to avoid any ambiguity
        request.term_id = ""

        return self.transport.request(
            method="GET",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.l10n.ListTranslationsOutput"),
            **kwargs,
        )

    def DeleteTranslation(self, request, **kwargs):
        path = "/terms/"+urllib.parse.quote(request.term_id)+"/translations/"+urllib.parse.quote(request.translation_id)

        # Cleanup URL parameters to avoid any ambiguity
        request.term_id = ""
        request.translation_id = ""

        return self.transport.request(
            method="DELETE",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.l10n.DeleteTranslationOutput"),
            **kwargs,
        )

    def SuggestTranslation(self, request, **kwargs):
        path = "/terms/"+urllib.parse.quote(request.term_id)+"/suggestions/"+urllib.parse.quote(request.locale)

        # Cleanup URL parameters to avoid any ambiguity
        request.term_id = ""
        request.locale = ""

        return self.transport.request(
            method="GET",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.l10n.SuggestTranslationOutput"),
            **kwargs,
        )

    def UpdateTranslation(self, request, **kwargs):
        path = "/terms/"+urllib.parse.quote(request.term_id)+"/translations/"+urllib.parse.quote(request.translation_id)

        # Cleanup URL parameters to avoid any ambiguity
        request.term_id = ""
        request.translation_id = ""

        return self.transport.request(
            method="PUT",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.l10n.UpdateTranslationOutput"),
            **kwargs,
        )

    def ApproveTranslation(self, request, **kwargs):
        path = "/terms/"+urllib.parse.quote(request.term_id)+"/translations/"+urllib.parse.quote(request.translation_id)+"/approve"

        # Cleanup URL parameters to avoid any ambiguity
        request.term_id = ""
        request.translation_id = ""

        return self.transport.request(
            method="POST",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.l10n.ApproveTranslationOutput"),
            **kwargs,
        )

    def RejectTranslation(self, request, **kwargs):
        path = "/terms/"+urllib.parse.quote(request.term_id)+"/translations/"+urllib.parse.quote(request.translation_id)+"/reject"

        # Cleanup URL parameters to avoid any ambiguity
        request.term_id = ""
        request.translation_id = ""

        return self.transport.request(
            method="POST",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.l10n.RejectTranslationOutput"),
            **kwargs,
        )

    def ImportTranslations(self, request, **kwargs):
        path = "/translations/"+urllib.parse.quote(request.locale)

        # Cleanup URL parameters to avoid any ambiguity
        request.locale = ""

        return self.transport.request(
            method="PUT",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.l10n.ImportTranslationsOutput"),
            **kwargs,
        )

    def ExportTranslations(self, request, **kwargs):
        path = "/translations/"+urllib.parse.quote(request.locale)

        # Cleanup URL parameters to avoid any ambiguity
        request.locale = ""

        return self.transport.request(
            method="GET",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.l10n.ExportTranslationsOutput"),
            **kwargs,
        )




from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Ticket(_message.Message):
    __slots__ = ["contest_id", "created_at", "ern", "id", "is_open", "is_read", "is_read_by_owner", "is_read_by_participant", "member_id", "message", "needs_reply", "participant_id", "subject"]
    CONTEST_ID_FIELD_NUMBER: _ClassVar[int]
    CREATED_AT_FIELD_NUMBER: _ClassVar[int]
    ERN_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    IS_OPEN_FIELD_NUMBER: _ClassVar[int]
    IS_READ_BY_OWNER_FIELD_NUMBER: _ClassVar[int]
    IS_READ_BY_PARTICIPANT_FIELD_NUMBER: _ClassVar[int]
    IS_READ_FIELD_NUMBER: _ClassVar[int]
    MEMBER_ID_FIELD_NUMBER: _ClassVar[int]
    MESSAGE_FIELD_NUMBER: _ClassVar[int]
    NEEDS_REPLY_FIELD_NUMBER: _ClassVar[int]
    PARTICIPANT_ID_FIELD_NUMBER: _ClassVar[int]
    SUBJECT_FIELD_NUMBER: _ClassVar[int]
    contest_id: str
    created_at: _timestamp_pb2.Timestamp
    ern: str
    id: str
    is_open: bool
    is_read: bool
    is_read_by_owner: bool
    is_read_by_participant: bool
    member_id: str
    message: str
    needs_reply: bool
    participant_id: str
    subject: str
    def __init__(self, id: _Optional[str] = ..., ern: _Optional[str] = ..., contest_id: _Optional[str] = ..., participant_id: _Optional[str] = ..., member_id: _Optional[str] = ..., subject: _Optional[str] = ..., message: _Optional[str] = ..., is_open: bool = ..., is_read_by_participant: bool = ..., is_read_by_owner: bool = ..., created_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., is_read: bool = ..., needs_reply: bool = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/content/fragment.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.ecm import content_pb2 as eolymp_dot_ecm_dot_content__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1d\x65olymp/content/fragment.proto\x12\x0e\x65olymp.content\x1a\x18\x65olymp/ecm/content.proto\"y\n\x08\x46ragment\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04path\x18\n \x01(\t\x12\x0e\n\x06locale\x18\x0b \x01(\t\x12\r\n\x05title\x18\x0c \x01(\t\x12$\n\x07\x63ontent\x18\x33 \x01(\x0b\x32\x13.eolymp.ecm.Content\x12\x0e\n\x06labels\x18\x64 \x03(\tB1Z/github.com/eolymp/go-sdk/eolymp/content;contentb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.content.fragment_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z/github.com/eolymp/go-sdk/eolymp/content;content'
  _FRAGMENT._serialized_start=75
  _FRAGMENT._serialized_end=196
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/acl/events.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.acl import acl_service_pb2 as eolymp_dot_acl_dot_acl__service__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x17\x65olymp/acl/events.proto\x12\neolymp.acl\x1a\x1c\x65olymp/acl/acl_service.proto\"\xc6\x01\n\x16PermissionChangeRecord\x12\x38\n\x02op\x18\x01 \x01(\x0e\x32,.eolymp.acl.PermissionChangeRecord.Operation\x12\x10\n\x08space_id\x18\x02 \x01(\t\x12*\n\npermission\x18\x03 \x01(\x0b\x32\x16.eolymp.acl.Permission\"4\n\tOperation\x12\x10\n\x0cNO_OPERATION\x10\x00\x12\t\n\x05GRANT\x10\x01\x12\n\n\x06REVOKE\x10\x02\x42)Z\'github.com/eolymp/go-sdk/eolymp/acl;aclb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.acl.events_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z\'github.com/eolymp/go-sdk/eolymp/acl;acl'
  _PERMISSIONCHANGERECORD._serialized_start=70
  _PERMISSIONCHANGERECORD._serialized_end=268
  _PERMISSIONCHANGERECORD_OPERATION._serialized_start=216
  _PERMISSIONCHANGERECORD_OPERATION._serialized_end=268
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/commerce/subscription_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.commerce import subscription_pb2 as eolymp_dot_commerce_dot_subscription__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*eolymp/commerce/subscription_service.proto\x12\x0f\x65olymp.commerce\x1a\"eolymp/annotations/ratelimit.proto\x1a\"eolymp/commerce/subscription.proto\"N\n\x17\x43reateSubscriptionInput\x12\x33\n\x0csubscription\x18\x01 \x01(\x0b\x32\x1d.eolymp.commerce.Subscription\"I\n\x18\x43reateSubscriptionOutput\x12\x17\n\x0fsubscription_id\x18\x01 \x01(\t\x12\x14\n\x0c\x63heckout_url\x18\x02 \x01(\t\"g\n\x17UpdateSubscriptionInput\x12\x17\n\x0fsubscription_id\x18\x01 \x01(\t\x12\x33\n\x0csubscription\x18\x02 \x01(\x0b\x32\x1d.eolymp.commerce.Subscription\"0\n\x18UpdateSubscriptionOutput\x12\x14\n\x0c\x63heckout_url\x18\x01 \x01(\t\"2\n\x17\x43\x61ncelSubscriptionInput\x12\x17\n\x0fsubscription_id\x18\x01 \x01(\t\"\x1a\n\x18\x43\x61ncelSubscriptionOutput2\x89\x03\n\x13SubscriptionService\x12z\n\x12\x43reateSubscription\x12(.eolymp.commerce.CreateSubscriptionInput\x1a).eolymp.commerce.CreateSubscriptionOutput\"\x0f\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x12z\n\x12UpdateSubscription\x12(.eolymp.commerce.UpdateSubscriptionInput\x1a).eolymp.commerce.UpdateSubscriptionOutput\"\x0f\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x12z\n\x12\x43\x61ncelSubscription\x12(.eolymp.commerce.CancelSubscriptionInput\x1a).eolymp.commerce.CancelSubscriptionOutput\"\x0f\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2B3Z1github.com/eolymp/go-sdk/eolymp/commerce;commerceb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.commerce.subscription_service_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z1github.com/eolymp/go-sdk/eolymp/commerce;commerce'
  _SUBSCRIPTIONSERVICE.methods_by_name['CreateSubscription']._options = None
  _SUBSCRIPTIONSERVICE.methods_by_name['CreateSubscription']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n2'
  _SUBSCRIPTIONSERVICE.methods_by_name['UpdateSubscription']._options = None
  _SUBSCRIPTIONSERVICE.methods_by_name['UpdateSubscription']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n2'
  _SUBSCRIPTIONSERVICE.methods_by_name['CancelSubscription']._options = None
  _SUBSCRIPTIONSERVICE.methods_by_name['CancelSubscription']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n2'
  _CREATESUBSCRIPTIONINPUT._serialized_start=135
  _CREATESUBSCRIPTIONINPUT._serialized_end=213
  _CREATESUBSCRIPTIONOUTPUT._serialized_start=215
  _CREATESUBSCRIPTIONOUTPUT._serialized_end=288
  _UPDATESUBSCRIPTIONINPUT._serialized_start=290
  _UPDATESUBSCRIPTIONINPUT._serialized_end=393
  _UPDATESUBSCRIPTIONOUTPUT._serialized_start=395
  _UPDATESUBSCRIPTIONOUTPUT._serialized_end=443
  _CANCELSUBSCRIPTIONINPUT._serialized_start=445
  _CANCELSUBSCRIPTIONINPUT._serialized_end=495
  _CANCELSUBSCRIPTIONOUTPUT._serialized_start=497
  _CANCELSUBSCRIPTIONOUTPUT._serialized_end=523
  _SUBSCRIPTIONSERVICE._serialized_start=526
  _SUBSCRIPTIONSERVICE._serialized_end=919
# @@protoc_insertion_point(module_scope)



from eolymp.annotations import http_pb2 as _http_pb2
from eolymp.annotations import ratelimit_pb2 as _ratelimit_pb2
from eolymp.annotations import scope_pb2 as _scope_pb2
from eolymp.atlas import library_service_pb2 as _library_service_pb2
from eolymp.atlas import version_pb2 as _version_pb2
from eolymp.wellknown import expression_pb2 as _expression_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ListVersionsInput(_message.Message):
    __slots__ = ["filters", "offset", "problem_id", "size"]
    class Filter(_message.Message):
        __slots__ = ["change_op", "change_path", "created_at", "created_by", "number"]
        CHANGE_OP_FIELD_NUMBER: _ClassVar[int]
        CHANGE_PATH_FIELD_NUMBER: _ClassVar[int]
        CREATED_AT_FIELD_NUMBER: _ClassVar[int]
        CREATED_BY_FIELD_NUMBER: _ClassVar[int]
        NUMBER_FIELD_NUMBER: _ClassVar[int]
        change_op: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionEnum]
        change_path: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionString]
        created_at: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionTimestamp]
        created_by: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionID]
        number: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionInt]
        def __init__(self, number: _Optional[_Iterable[_Union[_expression_pb2.ExpressionInt, _Mapping]]] = ..., created_by: _Optional[_Iterable[_Union[_expression_pb2.ExpressionID, _Mapping]]] = ..., created_at: _Optional[_Iterable[_Union[_expression_pb2.ExpressionTimestamp, _Mapping]]] = ..., change_op: _Optional[_Iterable[_Union[_expression_pb2.ExpressionEnum, _Mapping]]] = ..., change_path: _Optional[_Iterable[_Union[_expression_pb2.ExpressionString, _Mapping]]] = ...) -> None: ...
    FILTERS_FIELD_NUMBER: _ClassVar[int]
    OFFSET_FIELD_NUMBER: _ClassVar[int]
    PROBLEM_ID_FIELD_NUMBER: _ClassVar[int]
    SIZE_FIELD_NUMBER: _ClassVar[int]
    filters: ListVersionsInput.Filter
    offset: int
    problem_id: str
    size: int
    def __init__(self, problem_id: _Optional[str] = ..., offset: _Optional[int] = ..., size: _Optional[int] = ..., filters: _Optional[_Union[ListVersionsInput.Filter, _Mapping]] = ...) -> None: ...

class ListVersionsOutput(_message.Message):
    __slots__ = ["items", "total"]
    ITEMS_FIELD_NUMBER: _ClassVar[int]
    TOTAL_FIELD_NUMBER: _ClassVar[int]
    items: _containers.RepeatedCompositeFieldContainer[_version_pb2.Version]
    total: int
    def __init__(self, total: _Optional[int] = ..., items: _Optional[_Iterable[_Union[_version_pb2.Version, _Mapping]]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/discussion/forum.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.ecm import content_pb2 as eolymp_dot_ecm_dot_content__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1d\x65olymp/discussion/forum.proto\x12\x11\x65olymp.discussion\x1a\x18\x65olymp/ecm/content.proto\"\xcc\x01\n\x05\x46orum\x12\n\n\x02id\x18\x01 \x01(\t\x12\x11\n\tparent_id\x18\x02 \x01(\t\x12\x0c\n\x03url\x18\xaa\x05 \x01(\t\x12\x33\n\x05links\x18\xab\x05 \x03(\x0b\x32#.eolymp.discussion.Forum.LinksEntry\x12\r\n\x05title\x18\x64 \x01(\t\x12$\n\x07summary\x18\x65 \x01(\x0b\x32\x13.eolymp.ecm.Content\x1a,\n\nLinksEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\x37Z5github.com/eolymp/go-sdk/eolymp/discussion;discussionb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.discussion.forum_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z5github.com/eolymp/go-sdk/eolymp/discussion;discussion'
  _FORUM_LINKSENTRY._options = None
  _FORUM_LINKSENTRY._serialized_options = b'8\001'
  _FORUM._serialized_start=79
  _FORUM._serialized_end=283
  _FORUM_LINKSENTRY._serialized_start=239
  _FORUM_LINKSENTRY._serialized_end=283
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/discussion/subscription_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.annotations import scope_pb2 as eolymp_dot_annotations_dot_scope__pb2
from eolymp.discussion import subscription_pb2 as eolymp_dot_discussion_dot_subscription__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,eolymp/discussion/subscription_service.proto\x12\x11\x65olymp.discussion\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a\x1e\x65olymp/annotations/scope.proto\x1a$eolymp/discussion/subscription.proto\"\x1b\n\x19\x44\x65scribeSubscriptionInput\"S\n\x1a\x44\x65scribeSubscriptionOutput\x12\x35\n\x0csubscription\x18\x01 \x01(\x0b\x32\x1f.eolymp.discussion.Subscription\"P\n\x17UpdateSubscriptionInput\x12\x35\n\x0csubscription\x18\x01 \x01(\x0b\x32\x1f.eolymp.discussion.Subscription\"\x1a\n\x18UpdateSubscriptionOutput2\x91\x03\n\x13SubscriptionService\x12\xbe\x01\n\x14\x44\x65scribeSubscription\x12,.eolymp.discussion.DescribeSubscriptionInput\x1a-.eolymp.discussion.DescribeSubscriptionOutput\"I\x82\xe3\n \x8a\xe3\n\x1c\x64iscussion:subscription:read\xea\xe2\n\x0c\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\n\xf4\x03\x82\xd3\xe4\x93\x02\x0f\x12\r/subscription\x12\xb8\x01\n\x12UpdateSubscription\x12*.eolymp.discussion.UpdateSubscriptionInput\x1a+.eolymp.discussion.UpdateSubscriptionOutput\"I\x82\xe3\n!\x8a\xe3\n\x1d\x64iscussion:subscription:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\x0f\x1a\r/subscriptionB7Z5github.com/eolymp/go-sdk/eolymp/discussion;discussionb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.discussion.subscription_service_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z5github.com/eolymp/go-sdk/eolymp/discussion;discussion'
  _SUBSCRIPTIONSERVICE.methods_by_name['DescribeSubscription']._options = None
  _SUBSCRIPTIONSERVICE.methods_by_name['DescribeSubscription']._serialized_options = b'\202\343\n \212\343\n\034discussion:subscription:read\352\342\n\014\365\342\n\000\000\240A\370\342\n\364\003\202\323\344\223\002\017\022\r/subscription'
  _SUBSCRIPTIONSERVICE.methods_by_name['UpdateSubscription']._options = None
  _SUBSCRIPTIONSERVICE.methods_by_name['UpdateSubscription']._serialized_options = b'\202\343\n!\212\343\n\035discussion:subscription:write\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002\017\032\r/subscription'
  _DESCRIBESUBSCRIPTIONINPUT._serialized_start=204
  _DESCRIBESUBSCRIPTIONINPUT._serialized_end=231
  _DESCRIBESUBSCRIPTIONOUTPUT._serialized_start=233
  _DESCRIBESUBSCRIPTIONOUTPUT._serialized_end=316
  _UPDATESUBSCRIPTIONINPUT._serialized_start=318
  _UPDATESUBSCRIPTIONINPUT._serialized_end=398
  _UPDATESUBSCRIPTIONOUTPUT._serialized_start=400
  _UPDATESUBSCRIPTIONOUTPUT._serialized_end=426
  _SUBSCRIPTIONSERVICE._serialized_start=429
  _SUBSCRIPTIONSERVICE._serialized_end=830
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/atlas/snapshot.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.atlas import attachment_pb2 as eolymp_dot_atlas_dot_attachment__pb2
from eolymp.atlas import code_template_pb2 as eolymp_dot_atlas_dot_code__template__pb2
from eolymp.atlas import editorial_pb2 as eolymp_dot_atlas_dot_editorial__pb2
from eolymp.atlas import problem_pb2 as eolymp_dot_atlas_dot_problem__pb2
from eolymp.atlas import solution_pb2 as eolymp_dot_atlas_dot_solution__pb2
from eolymp.atlas import statement_pb2 as eolymp_dot_atlas_dot_statement__pb2
from eolymp.atlas import testing_config_pb2 as eolymp_dot_atlas_dot_testing__config__pb2
from eolymp.atlas import testing_test_pb2 as eolymp_dot_atlas_dot_testing__test__pb2
from eolymp.atlas import testing_testset_pb2 as eolymp_dot_atlas_dot_testing__testset__pb2
from eolymp.executor import interactor_pb2 as eolymp_dot_executor_dot_interactor__pb2
from eolymp.executor import verifier_pb2 as eolymp_dot_executor_dot_verifier__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1b\x65olymp/atlas/snapshot.proto\x12\x0c\x65olymp.atlas\x1a\x1d\x65olymp/atlas/attachment.proto\x1a eolymp/atlas/code_template.proto\x1a\x1c\x65olymp/atlas/editorial.proto\x1a\x1a\x65olymp/atlas/problem.proto\x1a\x1b\x65olymp/atlas/solution.proto\x1a\x1c\x65olymp/atlas/statement.proto\x1a!eolymp/atlas/testing_config.proto\x1a\x1f\x65olymp/atlas/testing_test.proto\x1a\"eolymp/atlas/testing_testset.proto\x1a eolymp/executor/interactor.proto\x1a\x1e\x65olymp/executor/verifier.proto\"\xe8\x03\n\x08Snapshot\x12&\n\x07problem\x18\x01 \x01(\x0b\x32\x15.eolymp.atlas.Problem\x12,\n\x07testing\x18\n \x01(\x0b\x32\x1b.eolymp.atlas.TestingConfig\x12*\n\x07\x63hecker\x18\x02 \x01(\x0b\x32\x19.eolymp.executor.Verifier\x12/\n\ninteractor\x18\x03 \x01(\x0b\x32\x1b.eolymp.executor.Interactor\x12+\n\nstatements\x18\x04 \x03(\x0b\x32\x17.eolymp.atlas.Statement\x12)\n\ttemplates\x18\x05 \x03(\x0b\x32\x16.eolymp.atlas.Template\x12-\n\x0b\x61ttachments\x18\x06 \x03(\x0b\x32\x18.eolymp.atlas.Attachment\x12\'\n\x08testsets\x18\x07 \x03(\x0b\x32\x15.eolymp.atlas.Testset\x12!\n\x05tests\x18\x08 \x03(\x0b\x32\x12.eolymp.atlas.Test\x12+\n\neditorials\x18\t \x03(\x0b\x32\x17.eolymp.atlas.Editorial\x12)\n\tsolutions\x18\x0b \x03(\x0b\x32\x16.eolymp.atlas.SolutionB-Z+github.com/eolymp/go-sdk/eolymp/atlas;atlasb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.atlas.snapshot_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z+github.com/eolymp/go-sdk/eolymp/atlas;atlas'
  _SNAPSHOT._serialized_start=398
  _SNAPSHOT._serialized_end=886
# @@protoc_insertion_point(module_scope)



from eolymp.annotations import ratelimit_pb2 as _ratelimit_pb2
from eolymp.commerce import price_pb2 as _price_pb2
from eolymp.commerce import product_pb2 as _product_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class CreateProductInput(_message.Message):
    __slots__ = ["product"]
    PRODUCT_FIELD_NUMBER: _ClassVar[int]
    product: _product_pb2.Product
    def __init__(self, product: _Optional[_Union[_product_pb2.Product, _Mapping]] = ...) -> None: ...

class CreateProductOutput(_message.Message):
    __slots__ = ["product_id"]
    PRODUCT_ID_FIELD_NUMBER: _ClassVar[int]
    product_id: str
    def __init__(self, product_id: _Optional[str] = ...) -> None: ...

class CreateProductPriceInput(_message.Message):
    __slots__ = ["price", "product_id"]
    PRICE_FIELD_NUMBER: _ClassVar[int]
    PRODUCT_ID_FIELD_NUMBER: _ClassVar[int]
    price: _price_pb2.Price
    product_id: str
    def __init__(self, product_id: _Optional[str] = ..., price: _Optional[_Union[_price_pb2.Price, _Mapping]] = ...) -> None: ...

class CreateProductPriceOutput(_message.Message):
    __slots__ = ["price_id"]
    PRICE_ID_FIELD_NUMBER: _ClassVar[int]
    price_id: str
    def __init__(self, price_id: _Optional[str] = ...) -> None: ...

class DeleteProductInput(_message.Message):
    __slots__ = ["product_id"]
    PRODUCT_ID_FIELD_NUMBER: _ClassVar[int]
    product_id: str
    def __init__(self, product_id: _Optional[str] = ...) -> None: ...

class DeleteProductOutput(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class DeleteProductPriceInput(_message.Message):
    __slots__ = ["price_id", "product_id"]
    PRICE_ID_FIELD_NUMBER: _ClassVar[int]
    PRODUCT_ID_FIELD_NUMBER: _ClassVar[int]
    price_id: str
    product_id: str
    def __init__(self, product_id: _Optional[str] = ..., price_id: _Optional[str] = ...) -> None: ...

class DeleteProductPriceOutput(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class DescribeProductInput(_message.Message):
    __slots__ = ["product_id"]
    PRODUCT_ID_FIELD_NUMBER: _ClassVar[int]
    product_id: str
    def __init__(self, product_id: _Optional[str] = ...) -> None: ...

class DescribeProductOutput(_message.Message):
    __slots__ = ["product"]
    PRODUCT_FIELD_NUMBER: _ClassVar[int]
    product: _product_pb2.Product
    def __init__(self, product: _Optional[_Union[_product_pb2.Product, _Mapping]] = ...) -> None: ...

class DescribeProductPriceInput(_message.Message):
    __slots__ = ["price_id", "product_id"]
    PRICE_ID_FIELD_NUMBER: _ClassVar[int]
    PRODUCT_ID_FIELD_NUMBER: _ClassVar[int]
    price_id: str
    product_id: str
    def __init__(self, product_id: _Optional[str] = ..., price_id: _Optional[str] = ...) -> None: ...

class DescribeProductPriceOutput(_message.Message):
    __slots__ = ["price"]
    PRICE_FIELD_NUMBER: _ClassVar[int]
    price: _price_pb2.Price
    def __init__(self, price: _Optional[_Union[_price_pb2.Price, _Mapping]] = ...) -> None: ...

class ListProductPricesInput(_message.Message):
    __slots__ = ["currency", "product_id"]
    CURRENCY_FIELD_NUMBER: _ClassVar[int]
    PRODUCT_ID_FIELD_NUMBER: _ClassVar[int]
    currency: str
    product_id: str
    def __init__(self, product_id: _Optional[str] = ..., currency: _Optional[str] = ...) -> None: ...

class ListProductPricesOutput(_message.Message):
    __slots__ = ["items"]
    ITEMS_FIELD_NUMBER: _ClassVar[int]
    items: _containers.RepeatedCompositeFieldContainer[_price_pb2.Price]
    def __init__(self, items: _Optional[_Iterable[_Union[_price_pb2.Price, _Mapping]]] = ...) -> None: ...

class UpdateProductInput(_message.Message):
    __slots__ = ["product", "product_id"]
    PRODUCT_FIELD_NUMBER: _ClassVar[int]
    PRODUCT_ID_FIELD_NUMBER: _ClassVar[int]
    product: _product_pb2.Product
    product_id: str
    def __init__(self, product_id: _Optional[str] = ..., product: _Optional[_Union[_product_pb2.Product, _Mapping]] = ...) -> None: ...

class UpdateProductOutput(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...



from eolymp.annotations import http_pb2 as _http_pb2
from eolymp.annotations import ratelimit_pb2 as _ratelimit_pb2
from eolymp.annotations import scope_pb2 as _scope_pb2
from eolymp.commerce import price_pb2 as _price_pb2
from eolymp.community import tier_pb2 as _tier_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class DescribeTierInput(_message.Message):
    __slots__ = ["locale", "render", "tier_id"]
    LOCALE_FIELD_NUMBER: _ClassVar[int]
    RENDER_FIELD_NUMBER: _ClassVar[int]
    TIER_ID_FIELD_NUMBER: _ClassVar[int]
    locale: str
    render: bool
    tier_id: str
    def __init__(self, tier_id: _Optional[str] = ..., render: bool = ..., locale: _Optional[str] = ...) -> None: ...

class DescribeTierOutput(_message.Message):
    __slots__ = ["tier"]
    TIER_FIELD_NUMBER: _ClassVar[int]
    tier: _tier_pb2.Tier
    def __init__(self, tier: _Optional[_Union[_tier_pb2.Tier, _Mapping]] = ...) -> None: ...

class ListTierPricesInput(_message.Message):
    __slots__ = ["currency", "tier_id"]
    CURRENCY_FIELD_NUMBER: _ClassVar[int]
    TIER_ID_FIELD_NUMBER: _ClassVar[int]
    currency: str
    tier_id: str
    def __init__(self, tier_id: _Optional[str] = ..., currency: _Optional[str] = ...) -> None: ...

class ListTierPricesOutput(_message.Message):
    __slots__ = ["items"]
    ITEMS_FIELD_NUMBER: _ClassVar[int]
    items: _containers.RepeatedCompositeFieldContainer[_price_pb2.Price]
    def __init__(self, items: _Optional[_Iterable[_Union[_price_pb2.Price, _Mapping]]] = ...) -> None: ...

class ListTiersInput(_message.Message):
    __slots__ = ["locale", "offset", "render", "size"]
    LOCALE_FIELD_NUMBER: _ClassVar[int]
    OFFSET_FIELD_NUMBER: _ClassVar[int]
    RENDER_FIELD_NUMBER: _ClassVar[int]
    SIZE_FIELD_NUMBER: _ClassVar[int]
    locale: str
    offset: int
    render: bool
    size: int
    def __init__(self, offset: _Optional[int] = ..., size: _Optional[int] = ..., render: bool = ..., locale: _Optional[str] = ...) -> None: ...

class ListTiersOutput(_message.Message):
    __slots__ = ["items", "total"]
    ITEMS_FIELD_NUMBER: _ClassVar[int]
    TOTAL_FIELD_NUMBER: _ClassVar[int]
    items: _containers.RepeatedCompositeFieldContainer[_tier_pb2.Tier]
    total: int
    def __init__(self, total: _Optional[int] = ..., items: _Optional[_Iterable[_Union[_tier_pb2.Tier, _Mapping]]] = ...) -> None: ...



from eolymp.ecm import content_pb2 as _content_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Document(_message.Message):
    __slots__ = ["content", "id", "labels", "locale", "path", "title"]
    CONTENT_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    LABELS_FIELD_NUMBER: _ClassVar[int]
    LOCALE_FIELD_NUMBER: _ClassVar[int]
    PATH_FIELD_NUMBER: _ClassVar[int]
    TITLE_FIELD_NUMBER: _ClassVar[int]
    content: _content_pb2.Content
    id: str
    labels: _containers.RepeatedScalarFieldContainer[str]
    locale: str
    path: str
    title: str
    def __init__(self, id: _Optional[str] = ..., path: _Optional[str] = ..., locale: _Optional[str] = ..., title: _Optional[str] = ..., content: _Optional[_Union[_content_pb2.Content, _Mapping]] = ..., labels: _Optional[_Iterable[str]] = ...) -> None: ...



from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Activity(_message.Message):
    __slots__ = ["complete_at", "created_at", "error", "id", "progress", "progress_at", "scoreboard_id", "started_at", "status", "total", "type"]
    class Status(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = []
    class Type(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = []
    COMPLETE: Activity.Status
    COMPLETE_AT_FIELD_NUMBER: _ClassVar[int]
    CREATED: Activity.Status
    CREATED_AT_FIELD_NUMBER: _ClassVar[int]
    ERROR: Activity.Status
    ERROR_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    NONE: Activity.Type
    PROGRESS_AT_FIELD_NUMBER: _ClassVar[int]
    PROGRESS_FIELD_NUMBER: _ClassVar[int]
    SCOREBOARD_ID_FIELD_NUMBER: _ClassVar[int]
    SCOREBOARD_REBUILD: Activity.Type
    STARTED: Activity.Status
    STARTED_AT_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    TOTAL_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    UNKNOWN: Activity.Status
    complete_at: _timestamp_pb2.Timestamp
    created_at: _timestamp_pb2.Timestamp
    error: str
    id: str
    progress: int
    progress_at: _timestamp_pb2.Timestamp
    scoreboard_id: str
    started_at: _timestamp_pb2.Timestamp
    status: Activity.Status
    total: int
    type: Activity.Type
    def __init__(self, id: _Optional[str] = ..., type: _Optional[_Union[Activity.Type, str]] = ..., status: _Optional[_Union[Activity.Status, str]] = ..., scoreboard_id: _Optional[str] = ..., created_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., started_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., progress_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., complete_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., progress: _Optional[int] = ..., total: _Optional[int] = ..., error: _Optional[str] = ...) -> None: ...



from eolymp.annotations import ratelimit_pb2 as _ratelimit_pb2
from eolymp.auth import claims_pb2 as _claims_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class IntrospectTokenInput(_message.Message):
    __slots__ = ["token"]
    TOKEN_FIELD_NUMBER: _ClassVar[int]
    token: str
    def __init__(self, token: _Optional[str] = ...) -> None: ...

class IntrospectTokenOutput(_message.Message):
    __slots__ = ["active", "claims", "expire", "scope"]
    ACTIVE_FIELD_NUMBER: _ClassVar[int]
    CLAIMS_FIELD_NUMBER: _ClassVar[int]
    EXPIRE_FIELD_NUMBER: _ClassVar[int]
    SCOPE_FIELD_NUMBER: _ClassVar[int]
    active: bool
    claims: _claims_pb2.Claims
    expire: _timestamp_pb2.Timestamp
    scope: str
    def __init__(self, active: bool = ..., scope: _Optional[str] = ..., expire: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., claims: _Optional[_Union[_claims_pb2.Claims, _Mapping]] = ...) -> None: ...

class IssueTokenInput(_message.Message):
    __slots__ = ["client_id", "client_secret", "code", "code_verifier", "grant_type", "password", "redirect_uri", "refresh_token", "scope", "username"]
    class GrantType(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = []
    AUTHORIZATION_CODE: IssueTokenInput.GrantType
    CLIENT_ID_FIELD_NUMBER: _ClassVar[int]
    CLIENT_SECRET_FIELD_NUMBER: _ClassVar[int]
    CODE_FIELD_NUMBER: _ClassVar[int]
    CODE_VERIFIER_FIELD_NUMBER: _ClassVar[int]
    EOLYMP_SIGNIN: IssueTokenInput.GrantType
    GRANT_TYPE_FIELD_NUMBER: _ClassVar[int]
    NONE: IssueTokenInput.GrantType
    PASSWORD: IssueTokenInput.GrantType
    PASSWORD_FIELD_NUMBER: _ClassVar[int]
    REDIRECT_URI_FIELD_NUMBER: _ClassVar[int]
    REFRESH_TOKEN: IssueTokenInput.GrantType
    REFRESH_TOKEN_FIELD_NUMBER: _ClassVar[int]
    SCOPE_FIELD_NUMBER: _ClassVar[int]
    USERNAME_FIELD_NUMBER: _ClassVar[int]
    client_id: str
    client_secret: str
    code: str
    code_verifier: str
    grant_type: IssueTokenInput.GrantType
    password: str
    redirect_uri: str
    refresh_token: str
    scope: str
    username: str
    def __init__(self, grant_type: _Optional[_Union[IssueTokenInput.GrantType, str]] = ..., username: _Optional[str] = ..., password: _Optional[str] = ..., client_id: _Optional[str] = ..., client_secret: _Optional[str] = ..., code: _Optional[str] = ..., code_verifier: _Optional[str] = ..., scope: _Optional[str] = ..., refresh_token: _Optional[str] = ..., redirect_uri: _Optional[str] = ...) -> None: ...

class IssueTokenOutput(_message.Message):
    __slots__ = ["access_token", "expires_in", "id_token", "refresh_token", "scope", "token_type"]
    ACCESS_TOKEN_FIELD_NUMBER: _ClassVar[int]
    EXPIRES_IN_FIELD_NUMBER: _ClassVar[int]
    ID_TOKEN_FIELD_NUMBER: _ClassVar[int]
    REFRESH_TOKEN_FIELD_NUMBER: _ClassVar[int]
    SCOPE_FIELD_NUMBER: _ClassVar[int]
    TOKEN_TYPE_FIELD_NUMBER: _ClassVar[int]
    access_token: str
    expires_in: int
    id_token: str
    refresh_token: str
    scope: str
    token_type: str
    def __init__(self, access_token: _Optional[str] = ..., token_type: _Optional[str] = ..., expires_in: _Optional[int] = ..., refresh_token: _Optional[str] = ..., scope: _Optional[str] = ..., id_token: _Optional[str] = ...) -> None: ...

class RequestAuthInput(_message.Message):
    __slots__ = ["client_id", "code_challenge", "code_challenge_method", "redirect_uri", "response_type", "scope", "state"]
    CLIENT_ID_FIELD_NUMBER: _ClassVar[int]
    CODE_CHALLENGE_FIELD_NUMBER: _ClassVar[int]
    CODE_CHALLENGE_METHOD_FIELD_NUMBER: _ClassVar[int]
    REDIRECT_URI_FIELD_NUMBER: _ClassVar[int]
    RESPONSE_TYPE_FIELD_NUMBER: _ClassVar[int]
    SCOPE_FIELD_NUMBER: _ClassVar[int]
    STATE_FIELD_NUMBER: _ClassVar[int]
    client_id: str
    code_challenge: str
    code_challenge_method: str
    redirect_uri: str
    response_type: str
    scope: str
    state: str
    def __init__(self, client_id: _Optional[str] = ..., code_challenge: _Optional[str] = ..., code_challenge_method: _Optional[str] = ..., redirect_uri: _Optional[str] = ..., response_type: _Optional[str] = ..., scope: _Optional[str] = ..., state: _Optional[str] = ...) -> None: ...

class RequestAuthOutput(_message.Message):
    __slots__ = ["authorization_code", "redirect_uri"]
    AUTHORIZATION_CODE_FIELD_NUMBER: _ClassVar[int]
    REDIRECT_URI_FIELD_NUMBER: _ClassVar[int]
    authorization_code: str
    redirect_uri: str
    def __init__(self, authorization_code: _Optional[str] = ..., redirect_uri: _Optional[str] = ...) -> None: ...

class RevokeTokenInput(_message.Message):
    __slots__ = ["token"]
    TOKEN_FIELD_NUMBER: _ClassVar[int]
    token: str
    def __init__(self, token: _Optional[str] = ...) -> None: ...

class RevokeTokenOutput(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class UserInfoInput(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class UserInfoOutput(_message.Message):
    __slots__ = ["claims"]
    CLAIMS_FIELD_NUMBER: _ClassVar[int]
    claims: _claims_pb2.Claims
    def __init__(self, claims: _Optional[_Union[_claims_pb2.Claims, _Mapping]] = ...) -> None: ...



from eolymp.annotations import endpoint_pb2 as _endpoint_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class Problem(_message.Message):
    __slots__ = ["difficulty", "id", "links", "number", "origin", "private", "topics", "url", "visible"]
    class LinksEntry(_message.Message):
        __slots__ = ["key", "value"]
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: str
        def __init__(self, key: _Optional[str] = ..., value: _Optional[str] = ...) -> None: ...
    DIFFICULTY_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    LINKS_FIELD_NUMBER: _ClassVar[int]
    NUMBER_FIELD_NUMBER: _ClassVar[int]
    ORIGIN_FIELD_NUMBER: _ClassVar[int]
    PRIVATE_FIELD_NUMBER: _ClassVar[int]
    TOPICS_FIELD_NUMBER: _ClassVar[int]
    URL_FIELD_NUMBER: _ClassVar[int]
    VISIBLE_FIELD_NUMBER: _ClassVar[int]
    difficulty: int
    id: str
    links: _containers.ScalarMap[str, str]
    number: int
    origin: str
    private: bool
    topics: _containers.RepeatedScalarFieldContainer[str]
    url: str
    visible: bool
    def __init__(self, id: _Optional[str] = ..., url: _Optional[str] = ..., links: _Optional[_Mapping[str, str]] = ..., number: _Optional[int] = ..., visible: bool = ..., private: bool = ..., origin: _Optional[str] = ..., topics: _Optional[_Iterable[str]] = ..., difficulty: _Optional[int] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/community/tier.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.ecm import content_pb2 as eolymp_dot_ecm_dot_content__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1b\x65olymp/community/tier.proto\x12\x10\x65olymp.community\x1a\x18\x65olymp/ecm/content.proto\"j\n\x04Tier\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0f\n\x07summary\x18\x06 \x01(\t\x12(\n\x0b\x64\x65scription\x18\x03 \x01(\x0b\x32\x13.eolymp.ecm.Content\x12\r\n\x05image\x18\x04 \x01(\tB5Z3github.com/eolymp/go-sdk/eolymp/community;communityb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.community.tier_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z3github.com/eolymp/go-sdk/eolymp/community;community'
  _TIER._serialized_start=75
  _TIER._serialized_end=181
# @@protoc_insertion_point(module_scope)
